/*
 * Copyright (c) 2024, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "hcs_control_driver.h"

/* External Functions */
tHCSResponseCode HCS_initializeDevice(TPS2HCS10Q1_CONFIG* config)
{
    tHCSResponseCode res;

    res.byte = HCS_writeRegister(config->crcConfig.reg,
                        config->crcConfig.value.word).byte;

    res.byte |= HCS_writeRegister(config->lpmConfig.reg,
                        config->lpmConfig.value.word).byte;

    res.byte |= HCS_writeRegister(config->faultMaskConfig.reg,
                        config->faultMaskConfig.value.word).byte;

    res.byte |= HCS_writeRegister(config->swState.reg,
                        config->swState.value.word).byte;

    res.byte |= HCS_writeRegister(config->devSAFConfig.reg,
                        config->devSAFConfig.value.word).byte;

    res.byte |= HCS_writeRegister(config->devConfig.reg,
                        config->devConfig.value.word).byte;

    res.byte |= HCS_writeRegister(config->adcConfig.reg,
                        config->adcConfig.value.word).byte;

    res.byte |= HCS_writeRegister(config->pwmCh1Config.reg,
                        config->pwmCh1Config.value.word).byte;

    res.byte |= HCS_writeRegister(config->ilimCh1Config.reg,
                        config->ilimCh1Config.value.word).byte;

    res.byte |= HCS_writeRegister(config->diagConfigCh1.reg,
                        config->diagConfigCh1.value.word).byte;

    res.byte |= HCS_writeRegister(config->i2tConfigCh1.reg,
                        config->i2tConfigCh1.value.word).byte;

    res.byte |= HCS_writeRegister(config->pwmCh2Config.reg,
                        config->pwmCh2Config.value.word).byte;

    res.byte |= HCS_writeRegister(config->ilimCh2Config.reg,
                        config->ilimCh2Config.value.word).byte;

    res.byte |= HCS_writeRegister(config->diagConfigCh2.reg,
                        config->diagConfigCh2.value.word).byte;

    res.byte |= HCS_writeRegister(config->i2tConfigCh2.reg,
                        config->i2tConfigCh2.value.word).byte;
    return res;
}

tHCSResponseCode HCS_wakeupDevice(void)
{
    /* Doing a dummy write to make sure the device is not in LPM */
    return (HCS_writeRegister(0xFF, 0xFFFF));
}

tHCSResponseCode HCS_updateConfig(TPS2HCS10Q1_CONFIG* config)
{
    tHCSResponseCode res;

    /* Doing a dummy write first so that the real value is read in the next
        transaction */
    res.byte = HCS_readRegister(config->crcConfig.reg,
                                &config->crcConfig.value.word).byte;

    res.byte = HCS_readRegister(config->crcConfig.reg,
                                &config->crcConfig.value.word).byte;

    res.byte |= HCS_readRegister(config->lpmConfig.reg,
                                &config->lpmConfig.value.word).byte;

    res.byte |= HCS_readRegister(config->faultMaskConfig.reg,
                                &config->faultMaskConfig.value.word).byte;

    res.byte |= HCS_readRegister(config->swState.reg,
                                &config->swState.value.word).byte;

    res.byte |= HCS_readRegister(config->devSAFConfig.reg,
                                &config->devSAFConfig.value.word).byte;

    res.byte |= HCS_readRegister(config->devConfig.reg,
                                &config->devConfig.value.word).byte;

    res.byte |= HCS_readRegister(config->adcConfig.reg,
                                &config->adcConfig.value.word).byte;

    res.byte |= HCS_readRegister(config->pwmCh1Config.reg,
                                 &config->pwmCh1Config.value.word).byte;

    res.byte |= HCS_readRegister(config->ilimCh1Config.reg,
                                &config->ilimCh1Config.value.word).byte;

    res.byte |= HCS_readRegister(config->diagConfigCh1.reg,
                                &config->diagConfigCh1.value.word).byte;

    res.byte |= HCS_readRegister(config->i2tConfigCh1.reg,
                                &config->i2tConfigCh1.value.word).byte;

    res.byte |= HCS_readRegister(config->pwmCh2Config.reg,
                                &config->pwmCh2Config.value.word).byte;

    res.byte |= HCS_readRegister(config->ilimCh2Config.reg,
                                &config->ilimCh2Config.value.word).byte;

    res.byte |= HCS_readRegister(config->diagConfigCh2.reg,
                                 &config->diagConfigCh2.value.word).byte;

    res.byte |= HCS_readRegister(config->i2tConfigCh2.reg,
                                 &config->i2tConfigCh2.value.word).byte;


    return (res);
}

tHCSResponseCode HCS_setSwitchState(uint8_t swState)
{
    return (HCS_writeRegister(TPS2HC10S_SW_STATE_REG, swState));
}

/* Generic register read/write functions  */
tHCSResponseCode HCS_writeRegister(uint8_t addr, uint16_t payload)
{
    tHCSResponseCode res;
    uint8_t respData[HCS_PACKET_SIZE];
    uint8_t writeData[HCS_PACKET_SIZE];

    /* Constructing the packet */
    tWriteHeader writeHeader =
    {
        .bits =
        {
            .addr = addr,
            .rw = 1,
        }
    };

    /* Copying the payload. Since this is just 2-bytes,
        we are doing manually. */
    writeData[0] = writeHeader.byte;
    writeData[2] = payload & 0xFF;
    writeData[1] = payload >> 8;

    /* Sending the write command */
    HCS_port_spiSendData(writeData, HCS_PACKET_SIZE, respData);

    res.byte = respData[0];

    return (res);
}

tHCSResponseCode HCS_readRegister(uint8_t addr, uint16_t* readValue)
{
    tHCSResponseCode res;
    uint8_t writeData[HCS_PACKET_SIZE];
    uint8_t respData[HCS_PACKET_SIZE];

    /* Constructing the packet */
    tWriteHeader readHeader =
    {
        .bits =
        {
            .addr = addr,
            .rw = 0,
        }
    };
    writeData[0] = readHeader.byte;

    /* Sending the read command */
    HCS_port_spiSendData(writeData, HCS_PACKET_SIZE, respData);

    /* Populating the response */
    *readValue = (respData[2] | (respData[1] << 8));

    /* Returning  whatever the error code was */
    res.byte = respData[0];
    return (res);
}

tHCSResponseCode HCS_gotoSleep(void)
{
    return (HCS_writeRegister(TPS2HC10S_SLEEP_REG, TPS2HC10S_SLEEP_SLEEP_MASK));
}

tHCSResponseCode HCS_gotoLPM(lpm_exit_curr_ch1_t ch1ExitCurrent,
                              lpm_exit_curr_ch2_t ch2ExitCurrent)
{
    tHCSResponseCode res;

    res.byte = HCS_writeRegister(TPS2HC10S_LPM_REG,
                                ch1ExitCurrent | ch2ExitCurrent |
                                TPS2HC10S_LPM_LPM_MASK).byte;

    return (res);
}

float_t HCS_convertVoltage(uint16_t rawValue)
{
    return ((50.092f * ((float_t)rawValue))) / 1705.341f;
}

float_t HCS_convertCurrent(uint16_t rawValue, uint16_t ksnsVal, uint16_t snsRes)
{
    return (((float_t)rawValue * ksnsVal * HCS_ADCREF) / (1023.0f * snsRes));
}

float_t HCS_convertTemperature(uint16_t rawValue)
{
    return ((((float_t)rawValue * 0.002737f) - 1.3815f) / (-0.003344f));
}

tHCSResponseCode HCS_getChannelFaultStatus(uint8_t chanNum,
                                           uint16_t *fltStatus)
{
    if(chanNum == 0)
    {
        return (HCS_readRegister(TPS2HC10S_FLT_STAT_CH1_REG, fltStatus));
    }
    else
    {
        return (HCS_readRegister(TPS2HC10S_FLT_STAT_CH2_REG, fltStatus));
    }
}

tHCSResponseCode HCS_getDeviceFaultSatus(uint16_t *fltStatus)
{
    return (HCS_readRegister(TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_REG,
                             fltStatus));
}
