/*
 * Copyright (c) 2024, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* MSP Specific Includes */
#include "hcs_driver_mspm0g3xx.h"
#include "ti/driverlib/dl_spi.h"
#include "ti/driverlib/dl_gpio.h"
#include "ti_msp_dl_config.h"

bool HCS_port_spiSendData(uint8_t *data, uint8_t len, uint8_t* respData)
{
    uint8_t ii;
    uint32_t tempData;

    if(data == NULL || respData == NULL)
    {
        return false;
    }

    /* If daisy chain is enabled, don't assert the SPI line here as this is
        done on the application level */
#ifndef HCS_ENABLE_DAISY_CHAIN
    HCS_port_assertSPI();
#endif

    /* Transfering all of the data */
    for(ii=0;ii<len;ii++)
    {
        DL_SPI_transmitDataBlocking8(HSS_SPI_INST, data[ii]);
        tempData = DL_SPI_receiveDataBlocking8(HSS_SPI_INST);
        respData[ii] = tempData & 0xFF;
    }

    while(DL_SPI_isBusy(HSS_SPI_INST));

    /* If daisy chain is enabled, don't deassert the SPI line here as this is
        done on the application level */
#ifndef HCS_ENABLE_DAISY_CHAIN
    HCS_port_deassertSPI();
#endif

    return true;
}

void HCS_port_assertSPI(void)
{
    DL_GPIO_clearPins(HCS_SPI_PORT, HCS_SPI_CS_PIN);
}

void HCS_port_deassertSPI(void)
{
    DL_GPIO_setPins(HCS_SPI_PORT, HCS_SPI_CS_PIN);
}
