/*
 * Copyright (c) 2024, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/*
 Generated on: Fri Feb  9 10:20:48 2024
 Using TPS2HC10S_component_out_Feb07.xml
 */

#ifndef TPS2HCS10_H
#define TPS2HCS10_H

#include <stdint.h>


/* --------- TPS2HC10S_CRC_CONFIG (0x01) ----------*/
/* DESCRIPTION: Configure CRC */

#define TPS2HC10S_CRC_CONFIG_REG 0x01

typedef union
{
    uint16_t word;
    struct
    {
        /* Set this bit to 1 to enable CRC check of SPI command frame. */
        unsigned CRC_EN : 1;
        /* Reserved */
        unsigned RESERVED_7 : 15;
    } bits;
} TPS2HC10S_CRC_CONFIG;

typedef struct TPS2HC10S_CRC_CONFIG_OBJ
{
    uint8_t reg;
    TPS2HC10S_CRC_CONFIG value;
} TPS2HC10S_CRC_CONFIG_OBJ;

#define TPS2HC10S_CRC_CONFIG_CRC_EN_MASK 0x01
#define TPS2HC10S_CRC_CONFIG_CRC_EN_OFS 0

typedef enum {
    crc_en_en_1_0x0 = 0x0,
    crc_en_en_2_0x1 = 0x1,
} crc_en_t;

#define TPS2HC10S_CRC_CONFIG_RESERVED_7_MASK 0xFFFE
#define TPS2HC10S_CRC_CONFIG_RESERVED_7_OFS 1

/* --------- TPS2HC10S_SLEEP (0x02) ----------*/
/* DESCRIPTION: Sets to go into SLEEP sate from ACTIVE or STANDBY state */

#define TPS2HC10S_SLEEP_REG 0x02

typedef union
{
    uint16_t word;
    struct
    {
        /* Setting this bit to 1 puts the device into SLEEP mode where everything
        * shuts off */
        unsigned SLEEP : 1;
        /* Reserved */
        unsigned RESERVED_1 : 15;
    } bits;
} TPS2HC10S_SLEEP;

typedef struct TPS2HC10S_SLEEP_OBJ
{
    uint8_t reg;
    TPS2HC10S_SLEEP value;
} TPS2HC10S_SLEEP_OBJ;

#define TPS2HC10S_SLEEP_SLEEP_MASK 0x01
#define TPS2HC10S_SLEEP_SLEEP_OFS 0
#define TPS2HC10S_SLEEP_RESERVED_1_MASK 0xFFFE
#define TPS2HC10S_SLEEP_RESERVED_1_OFS 1

/* --------- TPS2HC10S_LPM (0x03) ----------*/
/* DESCRIPTION: Sets to go in or out of Low power mode (LPM STATE) */

#define TPS2HC10S_LPM_REG 0x03

typedef union
{
    uint16_t word;
    struct
    {
        /* Setting this bit to 1 puts the device into LPM mode with the channels
        * enabled as per the device */
        unsigned LPM : 1;
        /* Set the threshold for exit from LPM mode due to load current increase
        * - CH1. */
        unsigned LPM_EXIT_CURR_CH1 : 2;
        /* Set the threshold for exit from LPM mode due to load current increase
        * - CH2. */
        unsigned LPM_EXIT_CURR_CH2 : 2;
        /* Reserved */
        unsigned RESERVED_5 : 2;
        /* Reserved */
        unsigned RESERVED_4 : 2;
        /* Reserved */
        unsigned RESERVED_3 : 7;
    } bits;
} TPS2HC10S_LPM;

typedef struct TPS2HC10S_LPM_OBJ
{
    uint8_t reg;
    TPS2HC10S_LPM value;
} TPS2HC10S_LPM_OBJ;

#define TPS2HC10S_LPM_LPM_MASK 0x01
#define TPS2HC10S_LPM_LPM_OFS 0
#define TPS2HC10S_LPM_LPM_EXIT_CURR_CH1_MASK 0x06
#define TPS2HC10S_LPM_LPM_EXIT_CURR_CH1_OFS 1

typedef enum {
    lpm_exit_curr_ch1_en_1_0x0 = 0x0,
    lpm_exit_curr_ch1_en_2_0x1 = 0x2,
    lpm_exit_curr_ch1_en_3_0x2 = 0x4,
    lpm_exit_curr_ch1_en_4_0x3 = 0x6,
} lpm_exit_curr_ch1_t;

#define TPS2HC10S_LPM_LPM_EXIT_CURR_CH2_MASK 0x18
#define TPS2HC10S_LPM_LPM_EXIT_CURR_CH2_OFS 3

typedef enum {
    lpm_exit_curr_ch2_en_1_0x0 = 0x0,
    lpm_exit_curr_ch2_en_2_0x1 = 0x8,
    lpm_exit_curr_ch2_en_3_0x2 = 0x10,
    lpm_exit_curr_ch2_en_4_0x3 = 0x18,
} lpm_exit_curr_ch2_t;

#define TPS2HC10S_LPM_RESERVED_5_MASK 0x60
#define TPS2HC10S_LPM_RESERVED_5_OFS 5
#define TPS2HC10S_LPM_RESERVED_4_MASK 0x180
#define TPS2HC10S_LPM_RESERVED_4_OFS 7
#define TPS2HC10S_LPM_RESERVED_3_MASK 0xFE00
#define TPS2HC10S_LPM_RESERVED_3_OFS 9

/* --------- TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE (0x04) ----------*/
/* DESCRIPTION: Faults for any channel and global faults */

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_REG 0x04

typedef union
{
    uint16_t word;
    struct
    {
        /* The bit is set if VBB supply is below the UV threshold at any time. The
        * fault bit is cleared if the GLOBAL_FAULT_TYPE register is read and the
        * UV condition is removed */
        unsigned VBB_UVLO : 1;
        /* The bit is set if VBB supply is below the UV warning (UV_WRN) threshold
        * at any time. The fault bit is cleared if the GLOBAL_FAULT_TYPE register
        * is read and the UV condition is removed */
        unsigned VBB_UV_WRN : 1;
        /* The bit is set if VDD supply is below the UVLO threshold at any time.
        * The fault bit is cleared if the GLOBAL_FAULT_TYPE register is read and
        * the UVLO condition is removed */
        unsigned VDD_UVLO : 1;
        /* The bit is set if the watchdog timer is enabled and there has not been
        * an acceptable SPI command in the watchdog timeout window. The fault bit
        * is latched and cleared only after read and the error is removed. */
        unsigned WD_ERR : 1;
        /* The bit is set if there is an SPI communication error either from format,
        * clock or CRC errors.The fault bit is latched and cleared only after read
        * and the error is removed. */
        unsigned SPI_ERR : 1;
        /* Reserved */
        unsigned RESERVED_8 : 1;
        /* The bit is indicative of whether a power on reset has occurred. */
        unsigned POR : 1;
        /* This bit is set high if the device is currently in the limp home mode.
        * */
        unsigned LIMPHOME_STAT : 1;
        /* The bit is set if there is a global fault reported in the FLT_GLOBAL_TYPE
        * register (Bits [7:0] : SPI error, watchdog error, VBB_UV, VBB_UV_WRN,
        * VDD_UVLO, POR fault or LIMPHOME_STAT bit is set. If FLT_LTCH_DIS bit is
        * set, then the fault bit is latched and is cleared only when the FLT_GLOBAL_TYPE
        * register is read and the fault condition no longer exists. */
        unsigned GLOBAL_ERR_WRN : 1;
        /* The bit is set if either the VDD_UVLO or VBB_UV are faults occur. If FLT_LTCH_DIS
        * bit is set, then the fault bit is latched and is cleared only when the
        * FLT_STAT_CHx register is read and the fault condition no longer exists.
        * */
        unsigned SUPPLY_FLT : 1;
        /* The bit is set if either there is a wire break in the on or off-state
        * fault in any one of the channels. If FLT_LTCH_DIS bit is set, then the
        * fault bit is latched and is cleared only when the FLT_STAT_CHx register
        * is read and the fault condition no longer exists */
        unsigned OL_FLT : 1;
        /* The bit is set if there is a short to VBB supply in the off-state fault
        * in any one of the channels. If FLT_LTCH_DIS bit is set, then the fault
        * bit is latched and is cleared only when the FLT_STAT_CHx register is read
        * and the fault condition no longer exists */
        unsigned SHRT_VBB_FLT : 1;
        /* The bit is set if there is a FET turn-off fault due to ovecurrent in any
        * one of the channels. If FLT_LTCH_DIS bit is set, then the fault bit is
        * latched and is cleared only when the FLT_STAT_CHx  register is read and
        * the fault condition no longer exists. */
        unsigned ILIMIT_FLT : 1;
        /* The bit is set if there is a thermal shutdown fault due to thermal overload
        * in any one of the channels. If FLT_LTCH_DIS bit is set, then the fault
        * bit is latched and is cleared only when the FLT_STAT_CHx register is read
        * and the fault condition no longer exists. */
        unsigned CHAN_TSD : 1;
        /* The bit is set if there is a fault during low power mode and the chip
        * comes back to the active state. If FLT_LTCH_DIS bit is set, then the fault
        * bit is latched and is cleared only when the FLT_STAT_CHx register is read
        * and the fault condition no longer exists */
        unsigned LPM_FLT : 1;
        /* The bit is set if there is a I2T fault due to ovecurrent in any one of
        * the channels. If FLT_LTCH_DIS bit is set, then the fault bit is latched
        * and is cleared only when the FLT_STAT_CHx  register is read and the fault
        * condition no longer exists. */
        unsigned I2T_FLT : 1;
    } bits;
} TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE;

typedef struct TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_OBJ
{
    uint8_t reg;
    TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE value;
} TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_OBJ;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_VBB_UVLO_MASK 0x01
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_VBB_UVLO_OFS 0

typedef enum {
    vbb_uvlo_en_1_0x0 = 0x0,
    vbb_uvlo_en_2_0x1 = 0x1,
} vbb_uvlo_t;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_VBB_UV_WRN_MASK 0x02
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_VBB_UV_WRN_OFS 1

typedef enum {
    vbb_uv_wrn_en_1_0x0 = 0x0,
    vbb_uv_wrn_en_2_0x1 = 0x2,
} vbb_uv_wrn_t;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_VDD_UVLO_MASK 0x04
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_VDD_UVLO_OFS 2

typedef enum {
    vdd_uvlo_en_1_0x0 = 0x0,
    vdd_uvlo_en_2_0x1 = 0x4,
} vdd_uvlo_t;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_WD_ERR_MASK 0x08
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_WD_ERR_OFS 3

typedef enum {
    wd_err_en_1_0x0 = 0x0,
    wd_err_en_2_0x1 = 0x8,
} wd_err_t;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_SPI_ERR_MASK 0x10
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_SPI_ERR_OFS 4

typedef enum {
    spi_err_en_1_0x0 = 0x0,
    spi_err_en_2_0x1 = 0x10,
} spi_err_t;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_RESERVED_8_MASK 0x20
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_RESERVED_8_OFS 5
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_POR_MASK 0x40
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_POR_OFS 6

typedef enum {
    por_en_1_0x0 = 0x0,
    por_en_2_0x1 = 0x40,
} por_t;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_LIMPHOME_STAT_MASK 0x80
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_LIMPHOME_STAT_OFS 7
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_GLOBAL_ERR_WRN_MASK 0x100
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_GLOBAL_ERR_WRN_OFS 8

typedef enum {
    global_err_wrn_en_1_0x0 = 0x0,
    global_err_wrn_en_2_0x1 = 0x100,
} global_err_wrn_t;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_SUPPLY_FLT_MASK 0x200
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_SUPPLY_FLT_OFS 9

typedef enum {
    supply_flt_en_1_0x0 = 0x0,
    supply_flt_en_2_0x1 = 0x200,
} supply_flt_t;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_OL_FLT_MASK 0x400
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_OL_FLT_OFS 10

typedef enum {
    ol_flt_en_1_0x0 = 0x0,
    ol_flt_en_2_0x1 = 0x400,
} ol_flt_t;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_SHRT_VBB_FLT_MASK 0x800
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_SHRT_VBB_FLT_OFS 11

typedef enum {
    shrt_vbb_flt_en_1_0x0 = 0x0,
    shrt_vbb_flt_en_2_0x1 = 0x800,
} shrt_vbb_flt_t;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_ILIMIT_FLT_MASK 0x1000
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_ILIMIT_FLT_OFS 12

typedef enum {
    ilimit_flt_en_1_0x0 = 0x0,
    ilimit_flt_en_2_0x1 = 0x1000,
} ilimit_flt_t;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_CHAN_TSD_MASK 0x2000
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_CHAN_TSD_OFS 13

typedef enum {
    chan_tsd_en_1_0x0 = 0x0,
    chan_tsd_en_2_0x1 = 0x2000,
} chan_tsd_t;

#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_LPM_FLT_MASK 0x4000
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_LPM_FLT_OFS 14
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_I2T_FLT_MASK 0x8000
#define TPS2HC10S_CH_FLT_TYPE_FAULT_GLOBAL_TYPE_I2T_FLT_OFS 15

/* --------- TPS2HC10S_FAULT_MASK (0x05) ----------*/
/* DESCRIPTION: Mask the reporting of the faults on the fault pin */

#define TPS2HC10S_FAULT_MASK_REG 0x05

typedef union
{
    uint16_t word;
    struct
    {
        /* The bit is set to mask the supply voltage VBB UVLO fault signaling on
        * the FLT pin output. */
        unsigned MASK_VBB_UVLO : 1;
        /* The bit is set to mask the SPI watchdog error (WD_ERR)  signaling in the
        *  FLT pin output and FAULT_TYPE_STAT register */
        unsigned MASK_WD_ERR : 1;
        /* The bit is set to mask the SPI error (SPI_ERR)  signaling in the  FLT
        * pin output and FAULT_TYPE_STAT register */
        unsigned MASK_SPI_ERR : 1;
        /* The bit is set to mask the signaling on-state open load fault on the FLT
        * pin */
        unsigned MASK_OL_ON : 1;
        /* The bit is set to mask the signaling off-state open load fault on the
        * FLT pin */
        unsigned MASK_OL_OFF : 1;
        /* The bit is set to mask the signaling off-state Short to VBB fault on the
        * FLT pin */
        unsigned MASK_SHRT_VBB : 1;
        /* The bit is set to mask the signaling overcurrent protection fault on the
        * FLT pin */
        unsigned MASK_ILIMIT : 1;
        /* Reserved */
        unsigned RESERVED_9 : 9;
    } bits;
} TPS2HC10S_FAULT_MASK;

typedef struct TPS2HC10S_FAULT_MASK_OBJ
{
    uint8_t reg;
    TPS2HC10S_FAULT_MASK value;
} TPS2HC10S_FAULT_MASK_OBJ;

#define TPS2HC10S_FAULT_MASK_MASK_VBB_UVLO_MASK 0x01
#define TPS2HC10S_FAULT_MASK_MASK_VBB_UVLO_OFS 0

typedef enum {
    mask_vbb_uvlo_en_1_0x0 = 0x0,
    mask_vbb_uvlo_en_2_0x1 = 0x1,
} mask_vbb_uvlo_t;

#define TPS2HC10S_FAULT_MASK_MASK_WD_ERR_MASK 0x02
#define TPS2HC10S_FAULT_MASK_MASK_WD_ERR_OFS 1

typedef enum {
    mask_wd_err_en_1_0x0 = 0x0,
    mask_wd_err_en_2_0x1 = 0x2,
} mask_wd_err_t;

#define TPS2HC10S_FAULT_MASK_MASK_SPI_ERR_MASK 0x04
#define TPS2HC10S_FAULT_MASK_MASK_SPI_ERR_OFS 2

typedef enum {
    mask_spi_err_en_1_0x0 = 0x0,
    mask_spi_err_en_2_0x1 = 0x4,
} mask_spi_err_t;

#define TPS2HC10S_FAULT_MASK_MASK_OL_ON_MASK 0x08
#define TPS2HC10S_FAULT_MASK_MASK_OL_ON_OFS 3

typedef enum {
    mask_ol_on_en_1_0x0 = 0x0,
    mask_ol_on_en_2_0x1 = 0x8,
} mask_ol_on_t;

#define TPS2HC10S_FAULT_MASK_MASK_OL_OFF_MASK 0x10
#define TPS2HC10S_FAULT_MASK_MASK_OL_OFF_OFS 4

typedef enum {
    mask_ol_off_en_1_0x0 = 0x0,
    mask_ol_off_en_2_0x1 = 0x10,
} mask_ol_off_t;

#define TPS2HC10S_FAULT_MASK_MASK_SHRT_VBB_MASK 0x20
#define TPS2HC10S_FAULT_MASK_MASK_SHRT_VBB_OFS 5

typedef enum {
    mask_shrt_vbb_en_1_0x0 = 0x0,
    mask_shrt_vbb_en_2_0x1 = 0x20,
} mask_shrt_vbb_t;

#define TPS2HC10S_FAULT_MASK_MASK_ILIMIT_MASK 0x40
#define TPS2HC10S_FAULT_MASK_MASK_ILIMIT_OFS 6

typedef enum {
    mask_ilimit_en_1_0x0 = 0x0,
    mask_ilimit_en_2_0x1 = 0x40,
} mask_ilimit_t;

#define TPS2HC10S_FAULT_MASK_RESERVED_9_MASK 0xFF80
#define TPS2HC10S_FAULT_MASK_RESERVED_9_OFS 7

/* --------- TPS2HC10S_ABIST_RESULT (0x06) ----------*/
/* DESCRIPTION: ABIST Diagniostic result */

#define TPS2HC10S_ABIST_RESULT_REG 0x06

typedef union
{
    uint16_t word;
    struct
    {
        /* This says whether or not the ABIST for the Bandgap passed (not implemented
        * in the present release) */
        unsigned BG_GOOD : 1;
        /* This says whether or not the ABIST for the VBB passed (not implemented
        * in the present release) */
        unsigned VBB_UVP_GOOD : 1;
        /* This says whether or not the ABIST for the ISNS passed (not implemented
        * in the present release) */
        unsigned ISNS_GOOD : 1;
        /* This says whether or not the ABIST for the ADC passed (not implemented
        * in the present release) */
        unsigned ADC_GOOD : 1;
        /* Reserved */
        unsigned RESERVED_11 : 12;
    } bits;
} TPS2HC10S_ABIST_RESULT;

typedef struct TPS2HC10S_ABIST_RESULT_OBJ
{
    uint8_t reg;
    TPS2HC10S_ABIST_RESULT value;
} TPS2HC10S_ABIST_RESULT_OBJ;

#define TPS2HC10S_ABIST_RESULT_BG_GOOD_MASK 0x01
#define TPS2HC10S_ABIST_RESULT_BG_GOOD_OFS 0

typedef enum {
    bg_good_en_1_0x0 = 0x0,
    bg_good_en_2_0x1 = 0x1,
} bg_good_t;

#define TPS2HC10S_ABIST_RESULT_VBB_UVP_GOOD_MASK 0x02
#define TPS2HC10S_ABIST_RESULT_VBB_UVP_GOOD_OFS 1

typedef enum {
    vbb_uvp_good_en_1_0x0 = 0x0,
    vbb_uvp_good_en_2_0x1 = 0x2,
} vbb_uvp_good_t;

#define TPS2HC10S_ABIST_RESULT_ISNS_GOOD_MASK 0x04
#define TPS2HC10S_ABIST_RESULT_ISNS_GOOD_OFS 2

typedef enum {
    isns_good_en_1_0x0 = 0x0,
    isns_good_en_2_0x1 = 0x4,
} isns_good_t;

#define TPS2HC10S_ABIST_RESULT_ADC_GOOD_MASK 0x08
#define TPS2HC10S_ABIST_RESULT_ADC_GOOD_OFS 3

typedef enum {
    adc_good_en_1_0x0 = 0x0,
    adc_good_en_2_0x1 = 0x8,
} adc_good_t;

#define TPS2HC10S_ABIST_RESULT_RESERVED_11_MASK 0xFFF0
#define TPS2HC10S_ABIST_RESULT_RESERVED_11_OFS 4

/* --------- TPS2HC10S_SW_STATE (0x07) ----------*/
/* DESCRIPTION: Turn on/off OUTx */

#define TPS2HC10S_SW_STATE_REG 0x07

typedef union
{
    uint16_t word;
    struct
    {
        /* Set this bit to 1 to turn on the FET and CH1 output ON */
        unsigned CH1_ON : 1;
        /* Set this bit to 1 to turn on the FET and CH2 output ON */
        unsigned CH2_ON : 1;
        /* Reserved */
        unsigned RESERVED_13 : 14;
    } bits;
} TPS2HC10S_SW_STATE;

typedef struct TPS2HC10S_SW_STATE_OBJ
{
    uint8_t reg;
    TPS2HC10S_SW_STATE value;
} TPS2HC10S_SW_STATE_OBJ;

#define TPS2HC10S_SW_STATE_CH1_ON_MASK 0x01
#define TPS2HC10S_SW_STATE_CH1_ON_OFS 0

typedef enum {
    ch1_on_en_1_0x0 = 0x0,
    ch1_on_en_2_0x1 = 0x1,
} ch1_on_t;

#define TPS2HC10S_SW_STATE_CH2_ON_MASK 0x02
#define TPS2HC10S_SW_STATE_CH2_ON_OFS 1

typedef enum {
    ch2_on_en_1_0x0 = 0x0,
    ch2_on_en_2_0x1 = 0x2,
} ch2_on_t;

#define TPS2HC10S_SW_STATE_RESERVED_13_MASK 0xFFFC
#define TPS2HC10S_SW_STATE_RESERVED_13_OFS 2

/* --------- TPS2HC10S_DEVICE_SAF (0x08) ----------*/
/* DESCRIPTION: Device BIST, LIMPHOME, and locking set by SPI */

#define TPS2HC10S_DEVICE_SAF_REG 0x08

typedef union
{
    uint16_t word;
    struct
    {
        /* Setting this bit to 1, enables the ADC function */
        unsigned ADC_EN : 1;
        /* Run the ABIST diaagnostics for the Band Gap good signal and update the
        * DIAG_RESULT register with the result. Reset bit back to 0 after ABIST has
        * been run */
        unsigned BG_ABIST_RUN : 1;
        /* Reserved */
        unsigned RESERVED_18 : 1;
        /* Run the ABIST diaagnostics for the ISNS good signal and update the DIAG_RESULT
        * register with the result. Not available when in I2T loop. Reset bit back
        * to 0 after ABIST has been run */
        unsigned ISNS_ABIST_RUN : 1;
        /* Run the ABIST diaagnostics for the ADC good signal and update the DIAG_RESULT
        * register with the result. Not available in current silicon, but will be
        * in the production version. Not available with in I2T loop. Reset bit back
        * to 0 after ABIST has been run */
        unsigned ADC_ABIST_RUN : 1;
        /* Decides what to do with the output for LH mode. Either on, off, keep or
        * use associated DI pin */
        unsigned CH1_LH_IN : 2;
        /* Decides what to do with the output for LH mode. Either on, off, keep or
        * use associated DI pin */
        unsigned CH2_LH_IN : 2;
        /* Reserved */
        unsigned RESERVED_17 : 2;
        /* Reserved */
        unsigned RESERVED_16 : 2;
        /* Reserved */
        unsigned RESERVED_15 : 3;
    } bits;
} TPS2HC10S_DEVICE_SAF;

typedef struct TPS2HC10S_DEVICE_SAF_OBJ
{
    uint8_t reg;
    TPS2HC10S_DEVICE_SAF value;
} TPS2HC10S_DEVICE_SAF_OBJ;

#define TPS2HC10S_DEVICE_SAF_ADC_EN_MASK 0x01
#define TPS2HC10S_DEVICE_SAF_ADC_EN_OFS 0

typedef enum {
    adc_en_en_1_0x0 = 0x0,
    adc_en_en_2_0x1 = 0x1,
} adc_en_t;

#define TPS2HC10S_DEVICE_SAF_BG_ABIST_RUN_MASK 0x02
#define TPS2HC10S_DEVICE_SAF_BG_ABIST_RUN_OFS 1

typedef enum {
    bg_abist_run_en_1_0x0 = 0x0,
    bg_abist_run_en_2_0x1 = 0x2,
} bg_abist_run_t;

#define TPS2HC10S_DEVICE_SAF_RESERVED_18_MASK 0x04
#define TPS2HC10S_DEVICE_SAF_RESERVED_18_OFS 2
#define TPS2HC10S_DEVICE_SAF_ISNS_ABIST_RUN_MASK 0x08
#define TPS2HC10S_DEVICE_SAF_ISNS_ABIST_RUN_OFS 3

typedef enum {
    isns_abist_run_en_1_0x0 = 0x0,
    isns_abist_run_en_2_0x1 = 0x8,
} isns_abist_run_t;

#define TPS2HC10S_DEVICE_SAF_ADC_ABIST_RUN_MASK 0x10
#define TPS2HC10S_DEVICE_SAF_ADC_ABIST_RUN_OFS 4

typedef enum {
    adc_abist_run_en_1_0x0 = 0x0,
    adc_abist_run_en_2_0x1 = 0x10,
} adc_abist_run_t;

#define TPS2HC10S_DEVICE_SAF_CH1_LH_IN_MASK 0x60
#define TPS2HC10S_DEVICE_SAF_CH1_LH_IN_OFS 5

typedef enum {
    ch1_lh_in_en_1_0x0 = 0x0,
    ch1_lh_in_en_2_0x1 = 0x20,
    ch1_lh_in_en_4_0x2 = 0x40,
    ch1_lh_in_en_3_0x3 = 0x60,
} ch1_lh_in_t;

#define TPS2HC10S_DEVICE_SAF_CH2_LH_IN_MASK 0x180
#define TPS2HC10S_DEVICE_SAF_CH2_LH_IN_OFS 7

typedef enum {
    ch2_lh_in_en_1_0x0 = 0x0,
    ch2_lh_in_en_2_0x1 = 0x80,
    ch2_lh_in_en_4_0x2 = 0x100,
    ch2_lh_in_en_3_0x3 = 0x180,
} ch2_lh_in_t;

#define TPS2HC10S_DEVICE_SAF_RESERVED_17_MASK 0x600
#define TPS2HC10S_DEVICE_SAF_RESERVED_17_OFS 9
#define TPS2HC10S_DEVICE_SAF_RESERVED_16_MASK 0x1800
#define TPS2HC10S_DEVICE_SAF_RESERVED_16_OFS 11
#define TPS2HC10S_DEVICE_SAF_RESERVED_15_MASK 0xE000
#define TPS2HC10S_DEVICE_SAF_RESERVED_15_OFS 13

/* --------- TPS2HC10S_DEV_CONFIG (0x09) ----------*/
/* DESCRIPTION: Device Configureable settings register */

#define TPS2HC10S_DEV_CONFIG_REG 0x09

typedef union
{
    uint16_t word;
    struct
    {
        /* Set this bit to 1 to not latch the fault bits in the register and cleared
        * on read. */
        unsigned FLT_LTCH_DIS : 1;
        /* Sets the timeout period for the SPI watchdog monitor. The watchdog timeout
        * is triggered if there is not a valid SPI command in the watchdog timeout
        * window */
        unsigned WD_TO : 2;
        /* The bit is set to enable the watchdog function. The watchdog is triggered
        * if there is not a valid SPI command in the watchdog timeout window */
        unsigned WD_EN : 1;
        /* Set this bit to 1 to signal that channels 1 and 2 (CH1 and CH2) are paralleled.
        * Write to this bit is valid only when all SW_STATE Channel enable bits are
        * 0 and not rewritten to 1 in the same frame. */
        unsigned PARALLEL_12 : 1;
        /* Reserved */
        unsigned RESERVED_22 : 1;
        /* Set this bit to 1 to disable the PWM delay between channels. */
        unsigned PWM_SHIFT_DIS : 1;
        /* Reserved */
        unsigned RESERVED_20 : 9;
    } bits;
} TPS2HC10S_DEV_CONFIG;

typedef struct TPS2HC10S_DEV_CONFIG_OBJ
{
    uint8_t reg;
    TPS2HC10S_DEV_CONFIG value;
} TPS2HC10S_DEV_CONFIG_OBJ;

#define TPS2HC10S_DEV_CONFIG_FLT_LTCH_DIS_MASK 0x01
#define TPS2HC10S_DEV_CONFIG_FLT_LTCH_DIS_OFS 0

typedef enum {
    flt_ltch_dis_en_1_0x0 = 0x0,
    flt_ltch_dis_en_2_0x1 = 0x1,
} flt_ltch_dis_t;

#define TPS2HC10S_DEV_CONFIG_WD_TO_MASK 0x06
#define TPS2HC10S_DEV_CONFIG_WD_TO_OFS 1

typedef enum {
    wd_to_en_1_0x0 = 0x0,
    wd_to_en_2_0x1 = 0x2,
    wd_to_en_3_0x2 = 0x4,
    wd_to_en_4_0x3 = 0x6,
} wd_to_t;

#define TPS2HC10S_DEV_CONFIG_WD_EN_MASK 0x08
#define TPS2HC10S_DEV_CONFIG_WD_EN_OFS 3

typedef enum {
    wd_en_en_1_0x0 = 0x0,
    wd_en_en_2_0x1 = 0x8,
} wd_en_t;

#define TPS2HC10S_DEV_CONFIG_PARALLEL_12_MASK 0x10
#define TPS2HC10S_DEV_CONFIG_PARALLEL_12_OFS 4

typedef enum {
    parallel_12_en_1_0x0 = 0x0,
    parallel_12_en_2_0x1 = 0x10,
} parallel_12_t;

#define TPS2HC10S_DEV_CONFIG_RESERVED_22_MASK 0x20
#define TPS2HC10S_DEV_CONFIG_RESERVED_22_OFS 5
#define TPS2HC10S_DEV_CONFIG_PWM_SHIFT_DIS_MASK 0x40
#define TPS2HC10S_DEV_CONFIG_PWM_SHIFT_DIS_OFS 6

typedef enum {
    pwm_shift_dis_en_1_0x0 = 0x0,
    pwm_shift_dis_en_2_0x1 = 0x40,
} pwm_shift_dis_t;

#define TPS2HC10S_DEV_CONFIG_RESERVED_20_MASK 0xFF80
#define TPS2HC10S_DEV_CONFIG_RESERVED_20_OFS 7

/* --------- TPS2HC10S_ADC_CONFIG (0x0A) ----------*/
/* DESCRIPTION: ADC configuration - disable ADC conversions or ADC entirely
 *             */

#define TPS2HC10S_ADC_CONFIG_REG 0x0A

typedef union
{
    uint16_t word;
    struct
    {
        /* Reserved */
        unsigned RESERVED_25 : 1;
        /* Set this bit to 1 to disable VBB_SNS functionality, exclude supply voltage
        * V_VBB conversion in the ADC conversion sequence. */
        unsigned ADC_VBB_DIS : 1;
        /* Set this bit to 1 to disable ISNS functionality, exclude ISNS conversion
        * in the ADC conversion sequence. */
        unsigned ADC_ISNS_DIS : 1;
        /* Set this bit to 1 to disable TEMP sense functionality, exclude TSNS conversion
        * in the ADC conversion sequence. */
        unsigned ADC_TSNS_DIS : 1;
        /* Set this bit to 1 to disable VOUT sense functionality, exclude VOUT conversion
        * in the ADC conversion sequence. */
        unsigned ADC_VSNS_DIS : 1;
        /* Reserved */
        unsigned RESERVED_24 : 11;
    } bits;
} TPS2HC10S_ADC_CONFIG;

typedef struct TPS2HC10S_ADC_CONFIG_OBJ
{
    uint8_t reg;
    TPS2HC10S_ADC_CONFIG value;
} TPS2HC10S_ADC_CONFIG_OBJ;

#define TPS2HC10S_ADC_CONFIG_RESERVED_25_MASK 0x01
#define TPS2HC10S_ADC_CONFIG_RESERVED_25_OFS 0
#define TPS2HC10S_ADC_CONFIG_ADC_VBB_DIS_MASK 0x02
#define TPS2HC10S_ADC_CONFIG_ADC_VBB_DIS_OFS 1

typedef enum {
    adc_vbb_dis_en_1_0x0 = 0x0,
    adc_vbb_dis_en_2_0x1 = 0x2,
} adc_vbb_dis_t;

#define TPS2HC10S_ADC_CONFIG_ADC_ISNS_DIS_MASK 0x04
#define TPS2HC10S_ADC_CONFIG_ADC_ISNS_DIS_OFS 2

typedef enum {
    adc_isns_dis_en_1_0x0 = 0x0,
    adc_isns_dis_en_2_0x1 = 0x4,
} adc_isns_dis_t;

#define TPS2HC10S_ADC_CONFIG_ADC_TSNS_DIS_MASK 0x08
#define TPS2HC10S_ADC_CONFIG_ADC_TSNS_DIS_OFS 3

typedef enum {
    adc_tsns_dis_en_1_0x0 = 0x0,
    adc_tsns_dis_en_2_0x1 = 0x8,
} adc_tsns_dis_t;

#define TPS2HC10S_ADC_CONFIG_ADC_VSNS_DIS_MASK 0x10
#define TPS2HC10S_ADC_CONFIG_ADC_VSNS_DIS_OFS 4

typedef enum {
    adc_vsns_dis_en_1_0x0 = 0x0,
    adc_vsns_dis_en_2_0x1 = 0x10,
} adc_vsns_dis_t;

#define TPS2HC10S_ADC_CONFIG_RESERVED_24_MASK 0xFFE0
#define TPS2HC10S_ADC_CONFIG_RESERVED_24_OFS 5

/* --------- TPS2HC10S_ADC_RESULT_VBB (0x0B) ----------*/
/* DESCRIPTION: ADC conversion result VBB */

#define TPS2HC10S_ADC_RESULT_VBB_REG 0x0B

typedef union
{
    uint16_t word;
    struct
    {
        /* ADC result (10-bits) from the conversion of the VBB voltage */
        unsigned ADC_RESULT_VBB : 10;
        /* Making sure the ADC conversion is new from the last time this was read
        * */
        unsigned VBB_RDY : 1;
        /* Reserved */
        unsigned RESERVED_26 : 5;
    } bits;
} TPS2HC10S_ADC_RESULT_VBB;

typedef struct TPS2HC10S_ADC_RESULT_VBB_OBJ
{
    uint8_t reg;
    TPS2HC10S_ADC_RESULT_VBB value;
} TPS2HC10S_ADC_RESULT_VBB_OBJ;

#define TPS2HC10S_ADC_RESULT_VBB_ADC_RESULT_VBB_MASK 0x3FF
#define TPS2HC10S_ADC_RESULT_VBB_ADC_RESULT_VBB_OFS 0
#define TPS2HC10S_ADC_RESULT_VBB_VBB_RDY_MASK 0x400
#define TPS2HC10S_ADC_RESULT_VBB_VBB_RDY_OFS 10

typedef enum {
    vbb_rdy_en_1_0x0 = 0x0,
    vbb_rdy_en_2_0x1 = 0x400,
} vbb_rdy_t;

#define TPS2HC10S_ADC_RESULT_VBB_RESERVED_26_MASK 0xF800
#define TPS2HC10S_ADC_RESULT_VBB_RESERVED_26_OFS 11

/* --------- TPS2HC10S_FLT_STAT_CH1 (0x0D) ----------*/
/* DESCRIPTION: Status of the channels and channel faults */

#define TPS2HC10S_FLT_STAT_CH1_REG 0x0D

typedef union
{
    uint16_t word;
    struct
    {
        /* The bit is set if FET temperature is above the overtemperature warning
        * threshold in CH1. The bit is cleared when over-temperature earning condition
        * does not exist anymore. */
        unsigned THERMAL_WRN_CH1 : 1;
        /* Has the open load on state threshold been triggered? Only valid if OL_ON_EN_CH1
        * is active. Device is in high resistance mode */
        unsigned OL_ON_CH1 : 1;
        /* The bit is set if the open load off state threshold been triggered. Only
        * valid if OL_OFF_EN_CH1 is active. Device is pulled up with the threshold
        * set by  OL_PULLUP_STR */
        unsigned OL_OFF_CH1 : 1;
        /* The bit is set if short to VBB has occurred at any time in CH1. The fault
        * is latched and cleared when the FLT_STAT_CH1 register is read and fault
        * condition does not exist anymore. OL_SHRTVBB_DIFF_CH1 must have been enabled
        * previously */
        unsigned SHRT_VBB_CH1 : 1;
        /* The bit is set if FET turn-off due to overcurrent has occurred at any
        * time in CH1. The fault is latched and cleared when the FLT_STAT_CH1 register
        * is read and fault condition does not exist anymore. Disabled if I2T mode
        * is enabled */
        unsigned ILIMIT_CH1 : 1;
        /* The bit is set if the thermal shutdown has occurred at any time in CH1.
        * The fault is latched and cleared when the FLT_STAT_CH1 register is read
        * and channel temperature has fallen below the thermal shutdown reset threshold.
        * */
        unsigned THERMAL_SD_CH1 : 1;
        /* This bit is set if this channel was the reason the device came out of
        * LPM regardless of why */
        unsigned LPM_WAKE_CH1 : 1;
        /* The bit is set if there is a fault from I2T setting (overcurrent). Only
        * can go high if I2T_EN is high and an associated fault occurs on that channel.
        * Cleared when FLT_STAT_CH1 register is read and fault condition does not
        * exist anymore */
        unsigned I2T_FLT_CH1 : 1;
        /* Reserved */
        unsigned RESERVED_36 : 1;
        /* Current state of the channel no matter which mode the device is in as
        * long as SPI is readable */
        unsigned SW_STATE_STAT_CH1 : 1;
        /* The bit is set if any type of real time fault (reverse current, thermal
        * shutdown, open load (on/off-state) or short to supply) occurs in CH1 */
        unsigned FLT_CH1 : 1;
        /* The bit is high if the channel has been latched off after a fault that
        * shut down the channel. Clears when the channel is toggled back on */
        unsigned LATCH_STAT_CH1 : 1;
        /* Reserved */
        unsigned RESERVED_35 : 1;
        /* Reserved */
        unsigned RESERVED_34 : 3;
    } bits;
} TPS2HC10S_FLT_STAT_CH1;

typedef struct TPS2HC10S_FLT_STAT_CH1_OBJ
{
    uint8_t reg;
    TPS2HC10S_FLT_STAT_CH1 value;
} TPS2HC10S_FLT_STAT_CH1_OBJ;

#define TPS2HC10S_FLT_STAT_CH1_THERMAL_WRN_CH1_MASK 0x01
#define TPS2HC10S_FLT_STAT_CH1_THERMAL_WRN_CH1_OFS 0

typedef enum {
    thermal_wrn_ch1_en_1_0x0 = 0x0,
    thermal_wrn_ch1_en_2_0x1 = 0x1,
} thermal_wrn_ch1_t;

#define TPS2HC10S_FLT_STAT_CH1_OL_ON_CH1_MASK 0x02
#define TPS2HC10S_FLT_STAT_CH1_OL_ON_CH1_OFS 1

typedef enum {
    ol_on_ch1_en_1_0x0 = 0x0,
    ol_on_ch1_en_2_0x1 = 0x2,
} ol_on_ch1_t;

#define TPS2HC10S_FLT_STAT_CH1_OL_OFF_CH1_MASK 0x04
#define TPS2HC10S_FLT_STAT_CH1_OL_OFF_CH1_OFS 2

typedef enum {
    ol_off_ch1_en_1_0x0 = 0x0,
    ol_off_ch1_en_2_0x1 = 0x4,
} ol_off_ch1_t;

#define TPS2HC10S_FLT_STAT_CH1_SHRT_VBB_CH1_MASK 0x08
#define TPS2HC10S_FLT_STAT_CH1_SHRT_VBB_CH1_OFS 3

typedef enum {
    shrt_vbb_ch1_en_1_0x0 = 0x0,
    shrt_vbb_ch1_en_2_0x1 = 0x8,
} shrt_vbb_ch1_t;

#define TPS2HC10S_FLT_STAT_CH1_ILIMIT_CH1_MASK 0x10
#define TPS2HC10S_FLT_STAT_CH1_ILIMIT_CH1_OFS 4

typedef enum {
    ilimit_ch1_en_1_0x0 = 0x0,
    ilimit_ch1_en_2_0x1 = 0x10,
} ilimit_ch1_t;

#define TPS2HC10S_FLT_STAT_CH1_THERMAL_SD_CH1_MASK 0x20
#define TPS2HC10S_FLT_STAT_CH1_THERMAL_SD_CH1_OFS 5

typedef enum {
    thermal_sd_ch1_en_1_0x0 = 0x0,
    thermal_sd_ch1_en_2_0x1 = 0x20,
} thermal_sd_ch1_t;

#define TPS2HC10S_FLT_STAT_CH1_LPM_WAKE_CH1_MASK 0x40
#define TPS2HC10S_FLT_STAT_CH1_LPM_WAKE_CH1_OFS 6

typedef enum {
    lpm_wake_ch1_en_1_0x0 = 0x0,
    lpm_wake_ch1_en_2_0x1 = 0x40,
} lpm_wake_ch1_t;

#define TPS2HC10S_FLT_STAT_CH1_I2T_FLT_CH1_MASK 0x80
#define TPS2HC10S_FLT_STAT_CH1_I2T_FLT_CH1_OFS 7

typedef enum {
    i2t_flt_ch1_en_1_0x0 = 0x0,
    i2t_flt_ch1_en_2_0x1 = 0x80,
} i2t_flt_ch1_t;

#define TPS2HC10S_FLT_STAT_CH1_RESERVED_36_MASK 0x100
#define TPS2HC10S_FLT_STAT_CH1_RESERVED_36_OFS 8
#define TPS2HC10S_FLT_STAT_CH1_SW_STATE_STAT_CH1_MASK 0x200
#define TPS2HC10S_FLT_STAT_CH1_SW_STATE_STAT_CH1_OFS 9

typedef enum {
    sw_state_stat_ch1_en_1_0x0 = 0x0,
    sw_state_stat_ch1_en_2_0x1 = 0x200,
} sw_state_stat_ch1_t;

#define TPS2HC10S_FLT_STAT_CH1_FLT_CH1_MASK 0x400
#define TPS2HC10S_FLT_STAT_CH1_FLT_CH1_OFS 10

typedef enum {
    flt_ch1_en_1_0x0 = 0x0,
    flt_ch1_en_2_0x1 = 0x400,
} flt_ch1_t;

#define TPS2HC10S_FLT_STAT_CH1_LATCH_STAT_CH1_MASK 0x800
#define TPS2HC10S_FLT_STAT_CH1_LATCH_STAT_CH1_OFS 11

typedef enum {
    latch_stat_ch1_en_1_0x0 = 0x0,
    latch_stat_ch1_en_2_0x1 = 0x800,
} latch_stat_ch1_t;

#define TPS2HC10S_FLT_STAT_CH1_RESERVED_35_MASK 0x1000
#define TPS2HC10S_FLT_STAT_CH1_RESERVED_35_OFS 12
#define TPS2HC10S_FLT_STAT_CH1_RESERVED_34_MASK 0xE000
#define TPS2HC10S_FLT_STAT_CH1_RESERVED_34_OFS 13

/* --------- TPS2HC10S_PWM_CH1 (0x0E) ----------*/
/* DESCRIPTION: Set all PWM configurations for channel 1 */

#define TPS2HC10S_PWM_CH1_REG 0x0E

typedef union
{
    uint16_t word;
    struct
    {
        /* Enable PWMing of the output if on cycle of PWM is #62#200us. If not return
        * error in FLT_STAT_CH1 register. PWM mode cannot be enabled unless CAP_CHRGx
        * [1:0] = 00 */
        unsigned PWM_EN_CH1 : 1;
        /* 8 bit to set duty cycle for PWM operation of CH1. Each bit ~0.39% duty
        * cycle, linearly up to 100% dutycycle. */
        unsigned PWM_DTY_CH1 : 8;
        /* Set the PWM frequency */
        unsigned PWM_FREQ_CH1 : 3;
        /* Reserved */
        unsigned RESERVED_37 : 4;
    } bits;
} TPS2HC10S_PWM_CH1;

typedef struct TPS2HC10S_PWM_CH1_OBJ
{
    uint8_t reg;
    TPS2HC10S_PWM_CH1 value;
} TPS2HC10S_PWM_CH1_OBJ;

#define TPS2HC10S_PWM_CH1_PWM_EN_CH1_MASK 0x01
#define TPS2HC10S_PWM_CH1_PWM_EN_CH1_OFS 0

typedef enum {
    pwm_en_ch1_en_1_0x0 = 0x0,
    pwm_en_ch1_en_2_0x1 = 0x1,
} pwm_en_ch1_t;

#define TPS2HC10S_PWM_CH1_PWM_DTY_CH1_MASK 0x1FE
#define TPS2HC10S_PWM_CH1_PWM_DTY_CH1_OFS 1
#define TPS2HC10S_PWM_CH1_PWM_FREQ_CH1_MASK 0xE00
#define TPS2HC10S_PWM_CH1_PWM_FREQ_CH1_OFS 9

typedef enum {
    pwm_freq_ch1_en_1_0x0 = 0x0,
    pwm_freq_ch1_en_2_0x1 = 0x200,
    pwm_freq_ch1_en_3_0x2 = 0x400,
    pwm_freq_ch1_en_4_0x3 = 0x600,
    pwm_freq_ch1_en_5_0x4 = 0x800,
    pwm_freq_ch1_en_6_0x5 = 0xa00,
    pwm_freq_ch1_en_7_0x6 = 0xc00,
    pwm_freq_ch1_en_8_0x7 = 0xe00,
} pwm_freq_ch1_t;

#define TPS2HC10S_PWM_CH1_RESERVED_37_MASK 0xF000
#define TPS2HC10S_PWM_CH1_RESERVED_37_OFS 12

/* --------- TPS2HC10S_ILIM_CONFIG_CH1 (0x0F) ----------*/
/* DESCRIPTION: Set all current limit configuration for channel 1 */

#define TPS2HC10S_ILIM_CONFIG_CH1_REG 0x0F

typedef union
{
    uint16_t word;
    struct
    {
        /* Setting the overcurrent protection threshold after the INRUSH_DURATION
        * period. */
        unsigned ILIMIT_SET_CH1 : 4;
        /* Overcurrent protection thresholds if CAP_CHRG_CH1 = 00. Becomes cap  charging
        * mode control bits when in cap charging mode. This means instead of having
        * an overcurrent protection threshold setting for an inrush period, the bits
        * are used to set the cap charging control bits setting either the dV/dt
        * rate (CAP_CHRG_CH1 = 01), current limit (regulation) level (CAP_CHRG_CH1
        * = 10) or pulsed current mode parameters.  (CAP_CHRG_CH1 = 11).
When CAP_CHRG_CH1
        * = 00, then the same table as ILIMIT_SET_CH1 applies for overcurrent protection
        * threshold during the INRUSH_DURATION.
When CAP_CHRG_CH1 = 10, then the
        * current limit threshold is below table with the value divided by 5.
When
        * CAP_CHRG_CH1 = 01, 4-bits will be used to set the dV/dt or voltage ramp
        * rate per the table below. Only the specified bit settings are supported.
        * */
        unsigned INRUSH_LIMIT_CH1_OR_CAP_CHRG_DVDT : 4;
        /* Sets the delay period during with inrush current limit level applies.
        * */
        unsigned INRUSH_DURATION_CH1 : 3;
        /* Enables the I2T functionality for Channel 1. I2T can be enabled before
        * the channel is enabled or charges up, but the I2T calculation will start
        * after the cap charge period ends If the cap charging mode is enabled (CAP_CHRG_CH1
        * [1:0] ne 00) . */
        unsigned I2T_EN_CH1 : 1;
        /* Puts the part into the capacitive load driving mode. Turns on the INRUSH_LIMIT_CH1
        * bits to set the overcurrent protection or cap charging levels within the
        * INRUSH_DURATION period and during that time there is no PWM or I2T */
        unsigned CAP_CHRG_CH1 : 2;
        /* When CAP_CHRG=11, sets the overcurrent turn-off threshold during inrush
        * phase and thus the peak current of the current pulse. */
        unsigned OCP_INRUSH_CH1 : 2;
    } bits;
} TPS2HC10S_ILIM_CONFIG_CH1;

typedef struct TPS2HC10S_ILIM_CONFIG_CH1_OBJ
{
    uint8_t reg;
    TPS2HC10S_ILIM_CONFIG_CH1 value;
} TPS2HC10S_ILIM_CONFIG_CH1_OBJ;

#define TPS2HC10S_ILIM_CONFIG_CH1_ILIMIT_SET_CH1_MASK 0x0F
#define TPS2HC10S_ILIM_CONFIG_CH1_ILIMIT_SET_CH1_OFS 0

typedef enum {
    ilimit_set_ch1_en_2_0x0 = 0x0,
    ilimit_set_ch1_en_5_0x1 = 0x1,
    ilimit_set_ch1_en_6_0x2 = 0x2,
    ilimit_set_ch1_en_7_0x3 = 0x3,
    ilimit_set_ch1_en_8_0x4 = 0x4,
    ilimit_set_ch1_en_9_0x5 = 0x5,
    ilimit_set_ch1_en_10_0x6 = 0x6,
    ilimit_set_ch1_en_11_0x7 = 0x7,
    ilimit_set_ch1_en_12_0x8 = 0x8,
    ilimit_set_ch1_en_13_0x9 = 0x9,
    ilimit_set_ch1_en_3_0xA = 0xa,
    ilimit_set_ch1_en_1_0xB = 0xb,
    ilimit_set_ch1_en_4_0xC = 0xc,
} ilimit_set_ch1_t;

#define TPS2HC10S_ILIM_CONFIG_CH1_INRUSH_LIMIT_CH1_OR_CAP_CHRG_DVDT_MASK 0xF0
#define TPS2HC10S_ILIM_CONFIG_CH1_INRUSH_LIMIT_CH1_OR_CAP_CHRG_DVDT_OFS 4

typedef enum {
    inrush_limit_ch1_or_cap_chrg_dvdt_en_5_0x3 = 0x30,
    inrush_limit_ch1_or_cap_chrg_dvdt_en_6_0x5 = 0x50,
    inrush_limit_ch1_or_cap_chrg_dvdt_en_7_0x6 = 0x60,
    inrush_limit_ch1_or_cap_chrg_dvdt_en_8_0x7 = 0x70,
    inrush_limit_ch1_or_cap_chrg_dvdt_en_9_0x9 = 0x90,
    inrush_limit_ch1_or_cap_chrg_dvdt_en_2_0xA = 0xa0,
    inrush_limit_ch1_or_cap_chrg_dvdt_en_4_0xB = 0xb0,
    inrush_limit_ch1_or_cap_chrg_dvdt_en_3_0xC = 0xc0,
    inrush_limit_ch1_or_cap_chrg_dvdt_en_1_0xD = 0xd0,
} inrush_limit_ch1_or_cap_chrg_dvdt_t;

#define TPS2HC10S_ILIM_CONFIG_CH1_INRUSH_DURATION_CH1_MASK 0x700
#define TPS2HC10S_ILIM_CONFIG_CH1_INRUSH_DURATION_CH1_OFS 8

typedef enum {
    inrush_duration_ch1_en_1_0x0 = 0x0,
    inrush_duration_ch1_en_2_0x1 = 0x100,
    inrush_duration_ch1_en_3_0x2 = 0x200,
    inrush_duration_ch1_en_4_0x3 = 0x300,
    inrush_duration_ch1_en_5_0x4 = 0x400,
    inrush_duration_ch1_en_6_0x5 = 0x500,
    inrush_duration_ch1_en_7_0x6 = 0x600,
    inrush_duration_ch1_en_8_0x7 = 0x700,
} inrush_duration_ch1_t;

#define TPS2HC10S_ILIM_CONFIG_CH1_I2T_EN_CH1_MASK 0x800
#define TPS2HC10S_ILIM_CONFIG_CH1_I2T_EN_CH1_OFS 11

typedef enum {
    i2t_en_ch1_en_1_0x0 = 0x0,
    i2t_en_ch1_en_2_0x1 = 0x800,
} i2t_en_ch1_t;

#define TPS2HC10S_ILIM_CONFIG_CH1_CAP_CHRG_CH1_MASK 0x3000
#define TPS2HC10S_ILIM_CONFIG_CH1_CAP_CHRG_CH1_OFS 12

typedef enum {
    cap_chrg_ch1_en_1_0x0 = 0x0,
    cap_chrg_ch1_en_2_0x1 = 0x1000,
    cap_chrg_ch1_en_3_0x2 = 0x2000,
    cap_chrg_ch1_en_4_0x3 = 0x3000,
} cap_chrg_ch1_t;

#define TPS2HC10S_ILIM_CONFIG_CH1_OCP_INRUSH_CH1_MASK 0xC000
#define TPS2HC10S_ILIM_CONFIG_CH1_OCP_INRUSH_CH1_OFS 14

typedef enum {
    ocp_inrush_ch1_en_1_0x0 = 0x0,
    ocp_inrush_ch1_en_2_0x1 = 0x4000,
    ocp_inrush_ch1_en_3_0xA = 0x28000,
    ocp_inrush_ch1_en_4_0xB = 0x2c000,
} ocp_inrush_ch1_t;


/* --------- TPS2HC10S_DIAG_CONFIG_CH1 (0x10) ----------*/
/* DESCRIPTION: Configuration register for channel 1 */

#define TPS2HC10S_DIAG_CONFIG_CH1_REG 0x10

typedef union
{
    uint16_t word;
    struct
    {
        /* Slew Rate set for ouput of CH1. 4 different slew rate values for adjustable
        * slew rate per electrical characteristics table */
        unsigned SLRT_CH1 : 2;
        /* If fault occurs that channel shuts down, this bit sets if the channel
        * auto retries or latches off */
        unsigned LATCH_CH1 : 1;
        /* Turns on the pull down to see if there is a short to VBB in the off state.
        * Cannot bet set high if channel is on or fault exists */
        unsigned SVBB_EN_CH1 : 1;
        /* Turns on the pull up to see if there is an open load in the off state.
        * Cannot bet set high if channel is on or fault exists */
        unsigned OL_OFF_EN_CH1 : 1;
        /* Sets the pullup current value (at the OUTx pins) by the off-state open
        * load detection circuit. */
        unsigned OL_PU_STR_CH1 : 2;
        /* Sets the blanking time for open load (ON-state  and OFF-state) and the
        * short_to_VBB faults before the fault is registered. */
        unsigned OL_SVBB_BLANK_CH1 : 2;
        /* Turns on a more accurate open load detection in the on state with KSNS
        * ratio scaled to lower value. This will set the FET into high Rdson mode
        * therefore this cannot be enabled if there is an existing fault on the channel
        * or the current is too high */
        unsigned OL_ON_EN_CH1 : 1;
        /* Turns on 8x scaling of voltage input to the ADC to improve the current
        * sense resolution */
        unsigned ISNS_SCALE_CH1 : 1;
        /* Sets the open load detection threshold in the on state. 2 bits to set
        * the open load detection threshold, not implemented in current silicon revision
        * */
        unsigned OL_ON_THLD_CH1 : 2;
        /* Set this bit to 1 to disable ISNS ADC functionality for this channel */
        unsigned ISNS_DIS_CH1 : 1;
        /* Set this bit to 1 to disable the ADC TSNS functionality for this channel
        * */
        unsigned TSNS_DIS_CH1 : 1;
        /* Set this bit to 1 to disable the VSNS ADC functionality for this channel
        * */
        unsigned VSNS_DIS_CH1 : 1;
    } bits;
} TPS2HC10S_DIAG_CONFIG_CH1;

typedef struct TPS2HC10S_DIAG_CONFIG_CH1_OBJ
{
    uint8_t reg;
    TPS2HC10S_DIAG_CONFIG_CH1 value;
} TPS2HC10S_DIAG_CONFIG_CH1_OBJ;

#define TPS2HC10S_DIAG_CONFIG_CH1_SLRT_CH1_MASK 0x03
#define TPS2HC10S_DIAG_CONFIG_CH1_SLRT_CH1_OFS 0
#define TPS2HC10S_DIAG_CONFIG_CH1_LATCH_CH1_MASK 0x04
#define TPS2HC10S_DIAG_CONFIG_CH1_LATCH_CH1_OFS 2

typedef enum {
    latch_ch1_en_1_0x0 = 0x0,
    latch_ch1_en_2_0x1 = 0x4,
} latch_ch1_t;

#define TPS2HC10S_DIAG_CONFIG_CH1_SVBB_EN_CH1_MASK 0x08
#define TPS2HC10S_DIAG_CONFIG_CH1_SVBB_EN_CH1_OFS 3
#define TPS2HC10S_DIAG_CONFIG_CH1_OL_OFF_EN_CH1_MASK 0x10
#define TPS2HC10S_DIAG_CONFIG_CH1_OL_OFF_EN_CH1_OFS 4
#define TPS2HC10S_DIAG_CONFIG_CH1_OL_PU_STR_CH1_MASK 0x60
#define TPS2HC10S_DIAG_CONFIG_CH1_OL_PU_STR_CH1_OFS 5

typedef enum {
    ol_pu_str_ch1_en_1_0x0 = 0x0,
    ol_pu_str_ch1_en_2_0x1 = 0x20,
    ol_pu_str_ch1_en_3_0x2 = 0x40,
    ol_pu_str_ch1_en_4_0x3 = 0x60,
} ol_pu_str_ch1_t;

#define TPS2HC10S_DIAG_CONFIG_CH1_OL_SVBB_BLANK_CH1_MASK 0x180
#define TPS2HC10S_DIAG_CONFIG_CH1_OL_SVBB_BLANK_CH1_OFS 7

typedef enum {
    ol_svbb_blank_ch1_en_1_0x0 = 0x0,
    ol_svbb_blank_ch1_en_2_0x1 = 0x80,
    ol_svbb_blank_ch1_en_3_0x2 = 0x100,
    ol_svbb_blank_ch1_en_4_0x3 = 0x180,
} ol_svbb_blank_ch1_t;

#define TPS2HC10S_DIAG_CONFIG_CH1_OL_ON_EN_CH1_MASK 0x200
#define TPS2HC10S_DIAG_CONFIG_CH1_OL_ON_EN_CH1_OFS 9

typedef enum {
    ol_on_en_ch1_en_1_0x0 = 0x0,
    ol_on_en_ch1_en_2_0x1 = 0x200,
} ol_on_en_ch1_t;

#define TPS2HC10S_DIAG_CONFIG_CH1_ISNS_SCALE_CH1_MASK 0x400
#define TPS2HC10S_DIAG_CONFIG_CH1_ISNS_SCALE_CH1_OFS 10

typedef enum {
    isns_scale_ch1_en_1_0x0 = 0x0,
    isns_scale_ch1_en_2_0x1 = 0x400,
} isns_scale_ch1_t;

#define TPS2HC10S_DIAG_CONFIG_CH1_OL_ON_THLD_CH1_MASK 0x1800
#define TPS2HC10S_DIAG_CONFIG_CH1_OL_ON_THLD_CH1_OFS 11

typedef enum {
    ol_on_thld_ch1_en_1_0x0 = 0x0,
    ol_on_thld_ch1_en_2_0x1 = 0x800,
    ol_on_thld_ch1_en_3_0x2 = 0x1000,
    ol_on_thld_ch1_en_4_0x3 = 0x1800,
} ol_on_thld_ch1_t;

#define TPS2HC10S_DIAG_CONFIG_CH1_ISNS_DIS_CH1_MASK 0x2000
#define TPS2HC10S_DIAG_CONFIG_CH1_ISNS_DIS_CH1_OFS 13

typedef enum {
    isns_dis_ch1_en_1_0x0 = 0x0,
    isns_dis_ch1_en_2_0x1 = 0x2000,
} isns_dis_ch1_t;

#define TPS2HC10S_DIAG_CONFIG_CH1_TSNS_DIS_CH1_MASK 0x4000
#define TPS2HC10S_DIAG_CONFIG_CH1_TSNS_DIS_CH1_OFS 14

typedef enum {
    tsns_dis_ch1_en_1_0x0 = 0x0,
    tsns_dis_ch1_en_2_0x1 = 0x4000,
} tsns_dis_ch1_t;

#define TPS2HC10S_DIAG_CONFIG_CH1_VSNS_DIS_CH1_MASK 0x8000
#define TPS2HC10S_DIAG_CONFIG_CH1_VSNS_DIS_CH1_OFS 15

typedef enum {
    vsns_dis_ch1_en_1_0x0 = 0x0,
    vsns_dis_ch1_en_2_0x1 = 0x8000,
} vsns_dis_ch1_t;


/* --------- TPS2HC10S_ADC_RESULT_CH1_I (0x11) ----------*/
/* DESCRIPTION: ADC conversion result load current sense CH1 */

#define TPS2HC10S_ADC_RESULT_CH1_I_REG 0x11

typedef union
{
    uint16_t word;
    struct
    {
        /* ADC result (10-bits) from the conversion of the current in CH1 */
        unsigned ADC_RESULT_CH1_I : 10;
        /* Making sure the ADC conversion is new from the last time this was read
        * */
        unsigned ISNS_RDY_CH1 : 1;
        /* Reserved */
        unsigned RESERVED_38 : 5;
    } bits;
} TPS2HC10S_ADC_RESULT_CH1_I;

typedef struct TPS2HC10S_ADC_RESULT_CH1_I_OBJ
{
    uint8_t reg;
    TPS2HC10S_ADC_RESULT_CH1_I value;
} TPS2HC10S_ADC_RESULT_CH1_I_OBJ;

#define TPS2HC10S_ADC_RESULT_CH1_I_ADC_RESULT_CH1_I_MASK 0x3FF
#define TPS2HC10S_ADC_RESULT_CH1_I_ADC_RESULT_CH1_I_OFS 0
#define TPS2HC10S_ADC_RESULT_CH1_I_ISNS_RDY_CH1_MASK 0x400
#define TPS2HC10S_ADC_RESULT_CH1_I_ISNS_RDY_CH1_OFS 10
#define TPS2HC10S_ADC_RESULT_CH1_I_RESERVED_38_MASK 0xF800
#define TPS2HC10S_ADC_RESULT_CH1_I_RESERVED_38_OFS 11

/* --------- TPS2HC10S_ADC_RESULT_CH1_T (0x12) ----------*/
/* DESCRIPTION: ADC conversion result TJ sense CH1 */

#define TPS2HC10S_ADC_RESULT_CH1_T_REG 0x12

typedef union
{
    uint16_t word;
    struct
    {
        /* ADC result (10-bits) from the conversion of the temperature in CH1 */
        unsigned ADC_RESULT_CH1_T : 10;
        /* Making sure the ADC conversion is new from the last time this was read
        * */
        unsigned TSNS_RDY_CH1 : 1;
        /* Reserved */
        unsigned RESERVED_39 : 5;
    } bits;
} TPS2HC10S_ADC_RESULT_CH1_T;

typedef struct TPS2HC10S_ADC_RESULT_CH1_T_OBJ
{
    uint8_t reg;
    TPS2HC10S_ADC_RESULT_CH1_T value;
} TPS2HC10S_ADC_RESULT_CH1_T_OBJ;

#define TPS2HC10S_ADC_RESULT_CH1_T_ADC_RESULT_CH1_T_MASK 0x3FF
#define TPS2HC10S_ADC_RESULT_CH1_T_ADC_RESULT_CH1_T_OFS 0
#define TPS2HC10S_ADC_RESULT_CH1_T_TSNS_RDY_CH1_MASK 0x400
#define TPS2HC10S_ADC_RESULT_CH1_T_TSNS_RDY_CH1_OFS 10
#define TPS2HC10S_ADC_RESULT_CH1_T_RESERVED_39_MASK 0xF800
#define TPS2HC10S_ADC_RESULT_CH1_T_RESERVED_39_OFS 11

/* --------- TPS2HC10S_ADC_RESULT_CH1_V (0x13) ----------*/
/* DESCRIPTION: ADC conversion result VOUT sense CH1 */

#define TPS2HC10S_ADC_RESULT_CH1_V_REG 0x13

typedef union
{
    uint16_t word;
    struct
    {
        /* ADC result (10-bits) from the conversion of the output voltage in CH1
        * */
        unsigned ADC_RESULT_CH1_V : 10;
        /* Making sure the ADC conversion is new from the last time this was read
        * */
        unsigned VSNS_RDY_CH1 : 1;
        /* Reserved */
        unsigned RESERVED_40 : 5;
    } bits;
} TPS2HC10S_ADC_RESULT_CH1_V;

typedef struct TPS2HC10S_ADC_RESULT_CH1_V_OBJ
{
    uint8_t reg;
    TPS2HC10S_ADC_RESULT_CH1_V value;
} TPS2HC10S_ADC_RESULT_CH1_V_OBJ;

#define TPS2HC10S_ADC_RESULT_CH1_V_ADC_RESULT_CH1_V_MASK 0x3FF
#define TPS2HC10S_ADC_RESULT_CH1_V_ADC_RESULT_CH1_V_OFS 0
#define TPS2HC10S_ADC_RESULT_CH1_V_VSNS_RDY_CH1_MASK 0x400
#define TPS2HC10S_ADC_RESULT_CH1_V_VSNS_RDY_CH1_OFS 10
#define TPS2HC10S_ADC_RESULT_CH1_V_RESERVED_40_MASK 0xF800
#define TPS2HC10S_ADC_RESULT_CH1_V_RESERVED_40_OFS 11

/* --------- TPS2HC10S_I2T_CONFIG_CH1 (0x14) ----------*/
/* DESCRIPTION: Set all I2T configuration bits */

#define TPS2HC10S_I2T_CONFIG_CH1_REG 0x14

typedef union
{
    uint16_t word;
    struct
    {
        /* 3 bits to set the nomial current value of Channel 1.  Assumes  sense resistor
        * of 700 ohms, otherwise scale the current with the resistor value relative
        * to 700 ohms */
        unsigned NOM_CUR_CH1 : 3;
        /* 4bits to Set Trip value for I2T functionality for Channel 1. Assumes
        * sense resistor of 700 ohms, otherwise scale the current with the resistor
        * value relative to 700 ohms and the threshold changes by the square of the
        * current. */
        unsigned I2T_TRIP_CH1 : 4;
        /* 2bits to set delayed turn-off current threshold  value for I2T functionality
        * for Channel 1. The threshold should be set below the maximum current sensed
        * with the sense resistor chosen. The current threshold assumes a sense resistor
        * of 700 ohms, otherwise scale the current with the resistor value relative
        * to 700 ohms */
        unsigned ISWCL_CH1 : 2;
        /* 2-bits to set delayed turn-off timer for Channel 1. Sets the time after
        * which the channel shuts down when the current exceeds ISWCL. */
        unsigned SWCL_DLY_TMR_CH1 : 2;
        /* Reserved */
        unsigned RESERVED_41 : 3;
        /* 2bits to Set cool down time for I2T functionality for Channel 1 (time
        * to retry after I2T shutdown. */
        unsigned TCLDN_CH1 : 2;
    } bits;
} TPS2HC10S_I2T_CONFIG_CH1;

typedef struct TPS2HC10S_I2T_CONFIG_CH1_OBJ
{
    uint8_t reg;
    TPS2HC10S_I2T_CONFIG_CH1 value;
} TPS2HC10S_I2T_CONFIG_CH1_OBJ;

#define TPS2HC10S_I2T_CONFIG_CH1_NOM_CUR_CH1_MASK 0x07
#define TPS2HC10S_I2T_CONFIG_CH1_NOM_CUR_CH1_OFS 0

typedef enum {
    nom_cur_ch1_en_1_0x0 = 0x0,
    nom_cur_ch1_en_2_0x1 = 0x1,
    nom_cur_ch1_en_3_0x2 = 0x2,
    nom_cur_ch1_en_4_0x3 = 0x3,
    nom_cur_ch1_en_5_0x4 = 0x4,
    nom_cur_ch1_en_6_0x5 = 0x5,
    nom_cur_ch1_en_7_0x6 = 0x6,
    nom_cur_ch1_en_8_0x7 = 0x7,
} nom_cur_ch1_t;

#define TPS2HC10S_I2T_CONFIG_CH1_I2T_TRIP_CH1_MASK 0x78
#define TPS2HC10S_I2T_CONFIG_CH1_I2T_TRIP_CH1_OFS 3

typedef enum {
    i2t_trip_ch1_en_3_0x0 = 0x0,
    i2t_trip_ch1_en_8_0x1 = 0x8,
    i2t_trip_ch1_en_9_0x2 = 0x10,
    i2t_trip_ch1_en_10_0x3 = 0x18,
    i2t_trip_ch1_en_11_0x4 = 0x20,
    i2t_trip_ch1_en_12_0x5 = 0x28,
    i2t_trip_ch1_en_13_0x6 = 0x30,
    i2t_trip_ch1_en_14_0x7 = 0x38,
    i2t_trip_ch1_en_15_0x8 = 0x40,
    i2t_trip_ch1_en_16_0x9 = 0x48,
    i2t_trip_ch1_en_1_0xA = 0x50,
    i2t_trip_ch1_en_4_0xB = 0x58,
    i2t_trip_ch1_en_2_0xC = 0x60,
    i2t_trip_ch1_en_6_0xD = 0x68,
    i2t_trip_ch1_en_5_0xE = 0x70,
    i2t_trip_ch1_en_7_0xF = 0x78,
} i2t_trip_ch1_t;

#define TPS2HC10S_I2T_CONFIG_CH1_ISWCL_CH1_MASK 0x180
#define TPS2HC10S_I2T_CONFIG_CH1_ISWCL_CH1_OFS 7

typedef enum {
    iswcl_ch1_en_1_0x0 = 0x0,
    iswcl_ch1_en_2_0x1 = 0x80,
    iswcl_ch1_en_3_0x2 = 0x100,
    iswcl_ch1_en_4_0x3 = 0x180,
} iswcl_ch1_t;

#define TPS2HC10S_I2T_CONFIG_CH1_SWCL_DLY_TMR_CH1_MASK 0x600
#define TPS2HC10S_I2T_CONFIG_CH1_SWCL_DLY_TMR_CH1_OFS 9

typedef enum {
    swcl_dly_tmr_ch1_en_1_0x0 = 0x0,
    swcl_dly_tmr_ch1_en_2_0x1 = 0x200,
    swcl_dly_tmr_ch1_en_3_0x2 = 0x400,
    swcl_dly_tmr_ch1_en_4_0x3 = 0x600,
} swcl_dly_tmr_ch1_t;

#define TPS2HC10S_I2T_CONFIG_CH1_RESERVED_41_MASK 0x3800
#define TPS2HC10S_I2T_CONFIG_CH1_RESERVED_41_OFS 11
#define TPS2HC10S_I2T_CONFIG_CH1_TCLDN_CH1_MASK 0xC000
#define TPS2HC10S_I2T_CONFIG_CH1_TCLDN_CH1_OFS 14

typedef enum {
    tcldn_ch1_en_1_0x0 = 0x0,
    tcldn_ch1_en_2_0x1 = 0x4000,
    tcldn_ch1_en_3_0x2 = 0x8000,
    tcldn_ch1_en_4_0x3 = 0xc000,
} tcldn_ch1_t;


/* --------- TPS2HC10S_FLT_STAT_CH2 (0x15) ----------*/
/* DESCRIPTION: Status of the channels and channel faults */

#define TPS2HC10S_FLT_STAT_CH2_REG 0x15

typedef union
{
    uint16_t word;
    struct
    {
        /* The bit is set if FET temperature is above the overtemperature warning
        * threshold in CH2. The bit is cleared when over-temperature earning condition
        * does not exist anymore. */
        unsigned THERMAL_WRN_CH2 : 1;
        /* Has the open load on state threshold been triggered? Only valid if OL_ON_EN_CH2
        * is active. Device is in high resistance mode */
        unsigned OL_ON_CH2 : 1;
        /* Has the open load off state threshold been triggered? Only valid if OL_OFF_EN_CH2
        * is active. Device is pulled up with the threshold set by  OL_PULLUP_STR
        * */
        unsigned OL_OFF_CH2 : 1;
        /* The bit is set if short to VBB has occurred at any time in CH2. The fault
        * is latched and cleared when the FLT_STAT_CH2 register is read and fault
        * condition does not exist anymore. OL_SHRTVBB_DIFF_CH2 must have been enabled
        * previously */
        unsigned SHRT_VBB_CH2 : 1;
        /* The bit is set if FET turn-off due to overcurrent has occurred at any
        * time in CH2. The fault is latched and cleared when the FLT_STAT_CH2 register
        * is read and fault condition does not exist anymore. */
        unsigned ILIMIT_CH2 : 1;
        /* The bit is set if the thermal shutdown has occurred at any time in CH2.
        * The fault is latched and cleared when the FLT_STAT_CH2 register is read
        * and channel temperature has fallen below the thermal shutdown reset threshold.
        * */
        unsigned THERMAL_SD_CH2 : 1;
        /* This bit is set if this channel was the reason the device came out of
        * LPM regardless of why */
        unsigned LPM_WAKE_CH2 : 1;
        /* The bit is set if there is a fault from I2T setting (overcurrent). Only
        * can go high if I2T_EN is high and an associated fault occurs on that channel.
        * Cleared when FLT_STAT_CH2 register is read and fault condition does not
        * exist anymore */
        unsigned I2T_FLT_CH2 : 1;
        /* Reserved */
        unsigned RESERVED_45 : 1;
        /* Current state of the channel no matter which mode the device is in as
        * long as SPI is readable */
        unsigned SW_STATE_STAT_CH2 : 1;
        /* The bit is set if any type of real time fault (reverse current, thermal
        * shutdown, open load (on/off-state) or short to supply) occurs in CH2 */
        unsigned FLT_CH2 : 1;
        /* The bit is high if the channel has been latched off after a fault that
        * shut down the channel. Clears when the channel is toggled back on */
        unsigned LATCH_STAT_CH2 : 1;
        /* Reserved */
        unsigned RESERVED_44 : 1;
        /* Reserved */
        unsigned RESERVED_43 : 3;
    } bits;
} TPS2HC10S_FLT_STAT_CH2;

typedef struct TPS2HC10S_FLT_STAT_CH2_OBJ
{
    uint8_t reg;
    TPS2HC10S_FLT_STAT_CH2 value;
} TPS2HC10S_FLT_STAT_CH2_OBJ;

#define TPS2HC10S_FLT_STAT_CH2_THERMAL_WRN_CH2_MASK 0x01
#define TPS2HC10S_FLT_STAT_CH2_THERMAL_WRN_CH2_OFS 0

typedef enum {
    thermal_wrn_ch2_en_1_0x0 = 0x0,
    thermal_wrn_ch2_en_2_0x1 = 0x1,
} thermal_wrn_ch2_t;

#define TPS2HC10S_FLT_STAT_CH2_OL_ON_CH2_MASK 0x02
#define TPS2HC10S_FLT_STAT_CH2_OL_ON_CH2_OFS 1

typedef enum {
    ol_on_ch2_en_1_0x0 = 0x0,
    ol_on_ch2_en_2_0x1 = 0x2,
} ol_on_ch2_t;

#define TPS2HC10S_FLT_STAT_CH2_OL_OFF_CH2_MASK 0x04
#define TPS2HC10S_FLT_STAT_CH2_OL_OFF_CH2_OFS 2

typedef enum {
    ol_off_ch2_en_1_0x0 = 0x0,
    ol_off_ch2_en_2_0x1 = 0x4,
} ol_off_ch2_t;

#define TPS2HC10S_FLT_STAT_CH2_SHRT_VBB_CH2_MASK 0x08
#define TPS2HC10S_FLT_STAT_CH2_SHRT_VBB_CH2_OFS 3

typedef enum {
    shrt_vbb_ch2_en_1_0x0 = 0x0,
    shrt_vbb_ch2_en_2_0x1 = 0x8,
} shrt_vbb_ch2_t;

#define TPS2HC10S_FLT_STAT_CH2_ILIMIT_CH2_MASK 0x10
#define TPS2HC10S_FLT_STAT_CH2_ILIMIT_CH2_OFS 4

typedef enum {
    ilimit_ch2_en_1_0x0 = 0x0,
    ilimit_ch2_en_2_0x1 = 0x10,
} ilimit_ch2_t;

#define TPS2HC10S_FLT_STAT_CH2_THERMAL_SD_CH2_MASK 0x20
#define TPS2HC10S_FLT_STAT_CH2_THERMAL_SD_CH2_OFS 5

typedef enum {
    thermal_sd_ch2_en_1_0x0 = 0x0,
    thermal_sd_ch2_en_2_0x1 = 0x20,
} thermal_sd_ch2_t;

#define TPS2HC10S_FLT_STAT_CH2_LPM_WAKE_CH2_MASK 0x40
#define TPS2HC10S_FLT_STAT_CH2_LPM_WAKE_CH2_OFS 6

typedef enum {
    lpm_wake_ch2_en_1_0x0 = 0x0,
    lpm_wake_ch2_en_2_0x1 = 0x40,
} lpm_wake_ch2_t;

#define TPS2HC10S_FLT_STAT_CH2_I2T_FLT_CH2_MASK 0x80
#define TPS2HC10S_FLT_STAT_CH2_I2T_FLT_CH2_OFS 7

typedef enum {
    i2t_flt_ch2_en_1_0x0 = 0x0,
    i2t_flt_ch2_en_2_0x1 = 0x80,
} i2t_flt_ch2_t;

#define TPS2HC10S_FLT_STAT_CH2_RESERVED_45_MASK 0x100
#define TPS2HC10S_FLT_STAT_CH2_RESERVED_45_OFS 8
#define TPS2HC10S_FLT_STAT_CH2_SW_STATE_STAT_CH2_MASK 0x200
#define TPS2HC10S_FLT_STAT_CH2_SW_STATE_STAT_CH2_OFS 9

typedef enum {
    sw_state_stat_ch2_en_1_0x0 = 0x0,
    sw_state_stat_ch2_en_2_0x1 = 0x200,
} sw_state_stat_ch2_t;

#define TPS2HC10S_FLT_STAT_CH2_FLT_CH2_MASK 0x400
#define TPS2HC10S_FLT_STAT_CH2_FLT_CH2_OFS 10

typedef enum {
    flt_ch2_en_1_0x0 = 0x0,
    flt_ch2_en_2_0x1 = 0x400,
} flt_ch2_t;

#define TPS2HC10S_FLT_STAT_CH2_LATCH_STAT_CH2_MASK 0x800
#define TPS2HC10S_FLT_STAT_CH2_LATCH_STAT_CH2_OFS 11

typedef enum {
    latch_stat_ch2_en_1_0x0 = 0x0,
    latch_stat_ch2_en_2_0x1 = 0x800,
} latch_stat_ch2_t;

#define TPS2HC10S_FLT_STAT_CH2_RESERVED_44_MASK 0x1000
#define TPS2HC10S_FLT_STAT_CH2_RESERVED_44_OFS 12
#define TPS2HC10S_FLT_STAT_CH2_RESERVED_43_MASK 0xE000
#define TPS2HC10S_FLT_STAT_CH2_RESERVED_43_OFS 13

/* --------- TPS2HC10S_PWM_CH2 (0x16) ----------*/
/* DESCRIPTION: Set all PWM configurations for channel 2 */

#define TPS2HC10S_PWM_CH2_REG 0x16

typedef union
{
    uint16_t word;
    struct
    {
        /* Enable PWMing of the output if on cycle of PWM is #62#200us. If not return
        * error in FLT_STAT_CH2 register. PWM mode cannot be enabled unless CAP_CHRGx
        * [1:0] = 00 */
        unsigned PWM_EN_CH2 : 1;
        /* 8 bit to set duty cycle for PWM operation of CH2. Each bit ~0.39% duty
        * cycle */
        unsigned PWM_DTY_CH2 : 8;
        /* Set the PWM frequency */
        unsigned PWM_FREQ_CH2 : 3;
        /* Reserved */
        unsigned RESERVED_46 : 4;
    } bits;
} TPS2HC10S_PWM_CH2;

typedef struct TPS2HC10S_PWM_CH2_OBJ
{
    uint8_t reg;
    TPS2HC10S_PWM_CH2 value;
} TPS2HC10S_PWM_CH2_OBJ;

#define TPS2HC10S_PWM_CH2_PWM_EN_CH2_MASK 0x01
#define TPS2HC10S_PWM_CH2_PWM_EN_CH2_OFS 0

typedef enum {
    pwm_en_ch2_en_1_0x0 = 0x0,
    pwm_en_ch2_en_2_0x1 = 0x1,
} pwm_en_ch2_t;

#define TPS2HC10S_PWM_CH2_PWM_DTY_CH2_MASK 0x1FE
#define TPS2HC10S_PWM_CH2_PWM_DTY_CH2_OFS 1
#define TPS2HC10S_PWM_CH2_PWM_FREQ_CH2_MASK 0xE00
#define TPS2HC10S_PWM_CH2_PWM_FREQ_CH2_OFS 9

typedef enum {
    pwm_freq_ch2_en_1_0x0 = 0x0,
    pwm_freq_ch2_en_2_0x1 = 0x200,
    pwm_freq_ch2_en_3_0x2 = 0x400,
    pwm_freq_ch2_en_4_0x3 = 0x600,
    pwm_freq_ch2_en_5_0x4 = 0x800,
    pwm_freq_ch2_en_6_0x5 = 0xa00,
    pwm_freq_ch2_en_7_0x6 = 0xc00,
    pwm_freq_ch2_en_8_0x7 = 0xe00,
} pwm_freq_ch2_t;

#define TPS2HC10S_PWM_CH2_RESERVED_46_MASK 0xF000
#define TPS2HC10S_PWM_CH2_RESERVED_46_OFS 12

/* --------- TPS2HC10S_ILIM_CONFIG_CH2 (0x17) ----------*/
/* DESCRIPTION: Set all current limit configuration for channel 2 */

#define TPS2HC10S_ILIM_CONFIG_CH2_REG 0x17

typedef union
{
    uint16_t word;
    struct
    {
        /* Setting the overcurrent protection threshold after the INRUSH_DURATION
        * period. */
        unsigned ILIMIT_SET_CH2 : 4;
        /* Overcurrent protection thresholds if CAP_CHRG_CH1 = 00. Becomes cap  charging
        * mode control bits when in cap charging mode. This means instead of having
        * an overcurrent protection threshold setting for an inrush period, the bits
        * are used to set the cap charging control bits setting either the dV/dt
        * rate (CAP_CHRG_CH1 = 01), current limit (regulation) level (CAP_CHRG_CH1
        * = 10) or pulsed current mode parameters.  (CAP_CHRG_CH1 = 11).
When CAP_CHRG_CH1
        * = 00, then the same table as ILIMIT_SET_CH1 applies for overcurrent protection
        * threshold during the INRUSH_DURATION.
When CAP_CHRG_CH1 = 10, then the
        * current limit threshold is below table with the value divided by 5.
When
        * CAP_CHRG_CH1 = 01, 4-bits will be used to set the dV/dt or voltage ramp
        * rate per the table below. Only the specified bit settings are supported.
        * */
        unsigned INRUSH_LIMIT_CH2_OR_CAP_CHRG_DVDT : 4;
        /* Sets the delay period during with inrush current limit level applies.
        * See table of delay settings in the datasheet. */
        unsigned INRUSH_DURATION_CH2 : 3;
        /* Enables the I2T functionality for Channel 2. I2T can be enabled before
        * the channel is enabled or charges up, but the I2T calculation will start
        * after the cap charge period ends If the cap charging mode is enabled (CAP_CHRG_CH2
        * [1:0] ne 00) . */
        unsigned I2T_EN_CH2 : 1;
        /* Puts the part into the capacitive load driving mode. Turns on the INRUSH_LIMIT_CH2
        * bits to set the overcurrent protection or cap charging levels within the
        * INRUSH_DURATION period and during that time there is no PWM or I2T */
        unsigned CAP_CHRG_CH2 : 2;
        /* When CAP_CHRG=11, sets the overcurrent turn-off threshold during inrush
        * phase and thus the peak current of the current pulse. */
        unsigned OCP_INRUSH_CH2 : 2;
    } bits;
} TPS2HC10S_ILIM_CONFIG_CH2;

typedef struct TPS2HC10S_ILIM_CONFIG_CH2_OBJ
{
    uint8_t reg;
    TPS2HC10S_ILIM_CONFIG_CH2 value;
} TPS2HC10S_ILIM_CONFIG_CH2_OBJ;

#define TPS2HC10S_ILIM_CONFIG_CH2_ILIMIT_SET_CH2_MASK 0x0F
#define TPS2HC10S_ILIM_CONFIG_CH2_ILIMIT_SET_CH2_OFS 0

typedef enum {
    ilimit_set_ch2_en_2_0x0 = 0x0,
    ilimit_set_ch2_en_5_0x1 = 0x1,
    ilimit_set_ch2_en_6_0x2 = 0x2,
    ilimit_set_ch2_en_7_0x3 = 0x3,
    ilimit_set_ch2_en_8_0x4 = 0x4,
    ilimit_set_ch2_en_9_0x5 = 0x5,
    ilimit_set_ch2_en_10_0x6 = 0x6,
    ilimit_set_ch2_en_11_0x7 = 0x7,
    ilimit_set_ch2_en_12_0x8 = 0x8,
    ilimit_set_ch2_en_13_0x9 = 0x9,
    ilimit_set_ch2_en_3_0xA = 0xa,
    ilimit_set_ch2_en_1_0xB = 0xb,
    ilimit_set_ch2_en_4_0xC = 0xc,
} ilimit_set_ch2_t;

#define TPS2HC10S_ILIM_CONFIG_CH2_INRUSH_LIMIT_CH2_OR_CAP_CHRG_DVDT_MASK 0xF0
#define TPS2HC10S_ILIM_CONFIG_CH2_INRUSH_LIMIT_CH2_OR_CAP_CHRG_DVDT_OFS 4

typedef enum {
    inrush_limit_ch2_or_cap_chrg_dvdt_en_5_0x3 = 0x30,
    inrush_limit_ch2_or_cap_chrg_dvdt_en_6_0x5 = 0x50,
    inrush_limit_ch2_or_cap_chrg_dvdt_en_7_0x6 = 0x60,
    inrush_limit_ch2_or_cap_chrg_dvdt_en_8_0x7 = 0x70,
    inrush_limit_ch2_or_cap_chrg_dvdt_en_9_0x9 = 0x90,
    inrush_limit_ch2_or_cap_chrg_dvdt_en_2_0xA = 0xa0,
    inrush_limit_ch2_or_cap_chrg_dvdt_en_4_0xB = 0xb0,
    inrush_limit_ch2_or_cap_chrg_dvdt_en_3_0xC = 0xc0,
    inrush_limit_ch2_or_cap_chrg_dvdt_en_1_0xD = 0xd0,
} inrush_limit_ch2_or_cap_chrg_dvdt_t;

#define TPS2HC10S_ILIM_CONFIG_CH2_INRUSH_DURATION_CH2_MASK 0x700
#define TPS2HC10S_ILIM_CONFIG_CH2_INRUSH_DURATION_CH2_OFS 8

typedef enum {
    inrush_duration_ch2_en_1_0x0 = 0x0,
    inrush_duration_ch2_en_2_0x1 = 0x100,
    inrush_duration_ch2_en_3_0x2 = 0x200,
    inrush_duration_ch2_en_4_0x3 = 0x300,
    inrush_duration_ch2_en_5_0x4 = 0x400,
    inrush_duration_ch2_en_6_0x5 = 0x500,
    inrush_duration_ch2_en_7_0x6 = 0x600,
    inrush_duration_ch2_en_8_0x7 = 0x700,
} inrush_duration_ch2_t;

#define TPS2HC10S_ILIM_CONFIG_CH2_I2T_EN_CH2_MASK 0x800
#define TPS2HC10S_ILIM_CONFIG_CH2_I2T_EN_CH2_OFS 11
#define TPS2HC10S_ILIM_CONFIG_CH2_CAP_CHRG_CH2_MASK 0x3000
#define TPS2HC10S_ILIM_CONFIG_CH2_CAP_CHRG_CH2_OFS 12

typedef enum {
    cap_chrg_ch2_en_1_0x0 = 0x0,
    cap_chrg_ch2_en_2_0x1 = 0x1000,
    cap_chrg_ch2_en_3_0x2 = 0x2000,
    cap_chrg_ch2_en_4_0x3 = 0x3000,
} cap_chrg_ch2_t;

#define TPS2HC10S_ILIM_CONFIG_CH2_OCP_INRUSH_CH2_MASK 0xC000
#define TPS2HC10S_ILIM_CONFIG_CH2_OCP_INRUSH_CH2_OFS 14

typedef enum {
    ocp_inrush_ch2_en_1_0x0 = 0x0,
    ocp_inrush_ch2_en_2_0x1 = 0x4000,
    ocp_inrush_ch2_en_3_0xA = 0x28000,
    ocp_inrush_ch2_en_4_0xB = 0x2c000,
} ocp_inrush_ch2_t;


/* --------- TPS2HC10S_DIAG_CONFIG_CH2 (0x18) ----------*/
/* DESCRIPTION: Configuration register for channel 2 */

#define TPS2HC10S_DIAG_CONFIG_CH2_REG 0x18

typedef union
{
    uint16_t word;
    struct
    {
        /* Slew Rate set for ouput of CH1. 4 different slew rate values for adjustable
        * slew rate per electrical characteristics table */
        unsigned SLRT_CH2 : 2;
        /* If fault occurs that channel shuts down, this bit sets if the channel
        * auto retries or latches off */
        unsigned LATCH_CH2 : 1;
        /* Turns on the pull down to see if there is a short to VBB in the off state.
        * Cannot bet set high if channel is on or fault exists */
        unsigned SVBB_EN_CH2 : 1;
        /* Turns on the pull up to see if there is an open load in the off state.
        * Cannot bet set high if channel is on or fault exists */
        unsigned OL_OFF_EN_CH2 : 1;
        /* Sets the pullup current value (at the OUTx pins) by the off-state open
        * load detection circuit. */
        unsigned OL_PU_STR_CH2 : 2;
        /* Sets the blanking time for open load (ON-state  and OFF-state) and the
        * short_to_VBB faults before the fault is registered. */
        unsigned OL_SVBB_BLANK_CH2 : 2;
        /* Turns on a more accurate open load detection in the on state with KSNS
        * ratio scaled to lower value. This will set the FET into high Rdson mode
        * therefore this cannot be enabled if there is an existing fault on the channel
        * or the current is too high */
        unsigned OL_ON_EN_CH2 : 1;
        /* Turns on 8x scaling of voltage input to the ADC to improve the current
        * sense resolution */
        unsigned ISNS_SCALE_CH2 : 1;
        /* Sets the open load detection threshold in the on state. 2 bits to set
        * the open load detection threshold, not implemented in current silicon revision
        * */
        unsigned OL_ON_THLD_CH2 : 2;
        /* Set this bit to 1 to disable ISNS ADC functionality for this channel */
        unsigned ISNS_DIS_CH2 : 1;
        /* Set this bit to 1 to disable the ADC TSNS functionality for this channel
        * */
        unsigned TSNS_DIS_CH2 : 1;
        /* Set this bit to 1 to disable the VSNS ADC functionality for this channel
        * */
        unsigned VSNS_DIS_CH2 : 1;
    } bits;
} TPS2HC10S_DIAG_CONFIG_CH2;

typedef struct TPS2HC10S_DIAG_CONFIG_CH2_OBJ
{
    uint8_t reg;
    TPS2HC10S_DIAG_CONFIG_CH2 value;
} TPS2HC10S_DIAG_CONFIG_CH2_OBJ;

#define TPS2HC10S_DIAG_CONFIG_CH2_SLRT_CH2_MASK 0x03
#define TPS2HC10S_DIAG_CONFIG_CH2_SLRT_CH2_OFS 0
#define TPS2HC10S_DIAG_CONFIG_CH2_LATCH_CH2_MASK 0x04
#define TPS2HC10S_DIAG_CONFIG_CH2_LATCH_CH2_OFS 2

typedef enum {
    latch_ch2_en_1_0x0 = 0x0,
    latch_ch2_en_2_0x1 = 0x4,
} latch_ch2_t;

#define TPS2HC10S_DIAG_CONFIG_CH2_SVBB_EN_CH2_MASK 0x08
#define TPS2HC10S_DIAG_CONFIG_CH2_SVBB_EN_CH2_OFS 3
#define TPS2HC10S_DIAG_CONFIG_CH2_OL_OFF_EN_CH2_MASK 0x10
#define TPS2HC10S_DIAG_CONFIG_CH2_OL_OFF_EN_CH2_OFS 4
#define TPS2HC10S_DIAG_CONFIG_CH2_OL_PU_STR_CH2_MASK 0x60
#define TPS2HC10S_DIAG_CONFIG_CH2_OL_PU_STR_CH2_OFS 5

typedef enum {
    ol_pu_str_ch2_en_1_0x0 = 0x0,
    ol_pu_str_ch2_en_2_0x1 = 0x20,
    ol_pu_str_ch2_en_3_0x2 = 0x40,
    ol_pu_str_ch2_en_4_0x3 = 0x60,
} ol_pu_str_ch2_t;

#define TPS2HC10S_DIAG_CONFIG_CH2_OL_SVBB_BLANK_CH2_MASK 0x180
#define TPS2HC10S_DIAG_CONFIG_CH2_OL_SVBB_BLANK_CH2_OFS 7

typedef enum {
    ol_svbb_blank_ch2_en_1_0x0 = 0x0,
    ol_svbb_blank_ch2_en_2_0x1 = 0x80,
    ol_svbb_blank_ch2_en_3_0x2 = 0x100,
    ol_svbb_blank_ch2_en_4_0x3 = 0x180,
} ol_svbb_blank_ch2_t;

#define TPS2HC10S_DIAG_CONFIG_CH2_OL_ON_EN_CH2_MASK 0x200
#define TPS2HC10S_DIAG_CONFIG_CH2_OL_ON_EN_CH2_OFS 9

typedef enum {
    ol_on_en_ch2_en_1_0x0 = 0x0,
    ol_on_en_ch2_en_2_0x1 = 0x200,
} ol_on_en_ch2_t;

#define TPS2HC10S_DIAG_CONFIG_CH2_ISNS_SCALE_CH2_MASK 0x400
#define TPS2HC10S_DIAG_CONFIG_CH2_ISNS_SCALE_CH2_OFS 10

typedef enum {
    isns_scale_ch2_en_1_0x0 = 0x0,
    isns_scale_ch2_en_2_0x1 = 0x400,
} isns_scale_ch2_t;

#define TPS2HC10S_DIAG_CONFIG_CH2_OL_ON_THLD_CH2_MASK 0x1800
#define TPS2HC10S_DIAG_CONFIG_CH2_OL_ON_THLD_CH2_OFS 11

typedef enum {
    ol_on_thld_ch2_en_1_0x0 = 0x0,
    ol_on_thld_ch2_en_2_0x1 = 0x800,
    ol_on_thld_ch2_en_3_0x2 = 0x1000,
    ol_on_thld_ch2_en_4_0x3 = 0x1800,
} ol_on_thld_ch2_t;

#define TPS2HC10S_DIAG_CONFIG_CH2_ISNS_DIS_CH2_MASK 0x2000
#define TPS2HC10S_DIAG_CONFIG_CH2_ISNS_DIS_CH2_OFS 13

typedef enum {
    isns_dis_ch2_en_1_0x0 = 0x0,
    isns_dis_ch2_en_2_0x1 = 0x2000,
} isns_dis_ch2_t;

#define TPS2HC10S_DIAG_CONFIG_CH2_TSNS_DIS_CH2_MASK 0x4000
#define TPS2HC10S_DIAG_CONFIG_CH2_TSNS_DIS_CH2_OFS 14

typedef enum {
    tsns_dis_ch2_en_1_0x0 = 0x0,
    tsns_dis_ch2_en_2_0x1 = 0x4000,
} tsns_dis_ch2_t;

#define TPS2HC10S_DIAG_CONFIG_CH2_VSNS_DIS_CH2_MASK 0x8000
#define TPS2HC10S_DIAG_CONFIG_CH2_VSNS_DIS_CH2_OFS 15

typedef enum {
    vsns_dis_ch2_en_1_0x0 = 0x0,
    vsns_dis_ch2_en_2_0x1 = 0x8000,
} vsns_dis_ch2_t;


/* --------- TPS2HC10S_ADC_RESULT_CH2_I (0x19) ----------*/
/* DESCRIPTION: ADC conversion result load current sense CH2 */

#define TPS2HC10S_ADC_RESULT_CH2_I_REG 0x19

typedef union
{
    uint16_t word;
    struct
    {
        /* ADC result (10-bits) from the conversion of the current in CH2 */
        unsigned ADC_RESULT_CH2_I : 10;
        /* Making sure the ADC conversion is new from the last time this was read
        * */
        unsigned ISNS_RDY_CH2 : 1;
        /* Reserved */
        unsigned RESERVED_47 : 5;
    } bits;
} TPS2HC10S_ADC_RESULT_CH2_I;

typedef struct TPS2HC10S_ADC_RESULT_CH2_I_OBJ
{
    uint8_t reg;
    TPS2HC10S_ADC_RESULT_CH2_I value;
} TPS2HC10S_ADC_RESULT_CH2_I_OBJ;

#define TPS2HC10S_ADC_RESULT_CH2_I_ADC_RESULT_CH2_I_MASK 0x3FF
#define TPS2HC10S_ADC_RESULT_CH2_I_ADC_RESULT_CH2_I_OFS 0
#define TPS2HC10S_ADC_RESULT_CH2_I_ISNS_RDY_CH2_MASK 0x400
#define TPS2HC10S_ADC_RESULT_CH2_I_ISNS_RDY_CH2_OFS 10
#define TPS2HC10S_ADC_RESULT_CH2_I_RESERVED_47_MASK 0xF800
#define TPS2HC10S_ADC_RESULT_CH2_I_RESERVED_47_OFS 11

/* --------- TPS2HC10S_ADC_RESULT_CH2_T (0x1A) ----------*/
/* DESCRIPTION: ADC conversion result TJ sense CH2 */

#define TPS2HC10S_ADC_RESULT_CH2_T_REG 0x1A

typedef union
{
    uint16_t word;
    struct
    {
        /* ADC result (10-bits) from the conversion of the temperature in CH2 */
        unsigned ADC_RESULT_CH2_T : 10;
        /* Making sure the ADC conversion is new from the last time this was read
        * */
        unsigned TSNS_RDY_CH2 : 1;
        /* Reserved */
        unsigned RESERVED_48 : 5;
    } bits;
} TPS2HC10S_ADC_RESULT_CH2_T;

typedef struct TPS2HC10S_ADC_RESULT_CH2_T_OBJ
{
    uint8_t reg;
    TPS2HC10S_ADC_RESULT_CH2_T value;
} TPS2HC10S_ADC_RESULT_CH2_T_OBJ;

#define TPS2HC10S_ADC_RESULT_CH2_T_ADC_RESULT_CH2_T_MASK 0x3FF
#define TPS2HC10S_ADC_RESULT_CH2_T_ADC_RESULT_CH2_T_OFS 0
#define TPS2HC10S_ADC_RESULT_CH2_T_TSNS_RDY_CH2_MASK 0x400
#define TPS2HC10S_ADC_RESULT_CH2_T_TSNS_RDY_CH2_OFS 10
#define TPS2HC10S_ADC_RESULT_CH2_T_RESERVED_48_MASK 0xF800
#define TPS2HC10S_ADC_RESULT_CH2_T_RESERVED_48_OFS 11

/* --------- TPS2HC10S_ADC_RESULT_CH2_V (0x1B) ----------*/
/* DESCRIPTION: ADC conversion result VOUT sense CH2 */

#define TPS2HC10S_ADC_RESULT_CH2_V_REG 0x1B

typedef union
{
    uint16_t word;
    struct
    {
        /* ADC result (10-bits) from the conversion of the output voltage in CH2
        * */
        unsigned ADC_RESULT_CH2_V : 10;
        /* Making sure the ADC conversion is new from the last time this was read
        * */
        unsigned VSNS_RDY_CH2 : 1;
        /* Reserved */
        unsigned RESERVED_49 : 5;
    } bits;
} TPS2HC10S_ADC_RESULT_CH2_V;

typedef struct TPS2HC10S_ADC_RESULT_CH2_V_OBJ
{
    uint8_t reg;
    TPS2HC10S_ADC_RESULT_CH2_V value;
} TPS2HC10S_ADC_RESULT_CH2_V_OBJ;

#define TPS2HC10S_ADC_RESULT_CH2_V_ADC_RESULT_CH2_V_MASK 0x3FF
#define TPS2HC10S_ADC_RESULT_CH2_V_ADC_RESULT_CH2_V_OFS 0
#define TPS2HC10S_ADC_RESULT_CH2_V_VSNS_RDY_CH2_MASK 0x400
#define TPS2HC10S_ADC_RESULT_CH2_V_VSNS_RDY_CH2_OFS 10
#define TPS2HC10S_ADC_RESULT_CH2_V_RESERVED_49_MASK 0xF800
#define TPS2HC10S_ADC_RESULT_CH2_V_RESERVED_49_OFS 11

/* --------- TPS2HC10S_I2T_CONFIG_CH2 (0x1C) ----------*/
/* DESCRIPTION: Set all I2T configuration bits */

#define TPS2HC10S_I2T_CONFIG_CH2_REG 0x1C

typedef union
{
    uint16_t word;
    struct
    {
        /* 3 bits to set the nomial current value of Channel 2.  Assumes  sense resistor
        * of 700 ohms, otherwise scale the current with the resistor value relative
        * to 700 ohms */
        unsigned NOM_CUR_CH2 : 3;
        /* 4-bits to Set Trip value for I2T functionality for Channel 1. Assumes
        *  sense resistor of 700 ohms, otherwise scale the current with the resistor
        * value relative to 700 ohms and the threshold changes by the square of the
        * current. */
        unsigned I2T_TRIP_CH2 : 4;
        /* 2-bits to set delayed turn-off current threshold  value for I2T functionality
        * for Channel 2. The threshold should be set below the maximum current sensed
        * with the sense resistor chosen. The current threshold assumes a sense resistor
        * of 700 ohms, otherwise scale the current with the resistor value relative
        * to 700 ohms */
        unsigned ISWCL_CH2 : 2;
        /* 2-bits to set delayed turn-off timer for Channel 2. Sets the time after
        * which the channel shuts down when the current exceeds ISWCL. */
        unsigned SWCL_DLY_TMR_CH2 : 2;
        /* Reserved */
        unsigned RESERVED_50 : 3;
        /* 2bits to Set cool down time for I2T functionality for Channel 2 (time
        * to retry after I2T shutdown. */
        unsigned TCLDN_CH2 : 2;
    } bits;
} TPS2HC10S_I2T_CONFIG_CH2;

typedef struct TPS2HC10S_I2T_CONFIG_CH2_OBJ
{
    uint8_t reg;
    TPS2HC10S_I2T_CONFIG_CH2 value;
} TPS2HC10S_I2T_CONFIG_CH2_OBJ;

#define TPS2HC10S_I2T_CONFIG_CH2_NOM_CUR_CH2_MASK 0x07
#define TPS2HC10S_I2T_CONFIG_CH2_NOM_CUR_CH2_OFS 0

typedef enum {
    nom_cur_ch2_en_1_0x0 = 0x0,
    nom_cur_ch2_en_2_0x1 = 0x1,
    nom_cur_ch2_en_3_0x2 = 0x2,
    nom_cur_ch2_en_4_0x3 = 0x3,
    nom_cur_ch2_en_5_0x4 = 0x4,
    nom_cur_ch2_en_6_0x5 = 0x5,
    nom_cur_ch2_en_7_0x6 = 0x6,
    nom_cur_ch2_en_8_0x7 = 0x7,
} nom_cur_ch2_t;

#define TPS2HC10S_I2T_CONFIG_CH2_I2T_TRIP_CH2_MASK 0x78
#define TPS2HC10S_I2T_CONFIG_CH2_I2T_TRIP_CH2_OFS 3

typedef enum {
    i2t_trip_ch2_en_3_0x0 = 0x0,
    i2t_trip_ch2_en_8_0x1 = 0x8,
    i2t_trip_ch2_en_9_0x2 = 0x10,
    i2t_trip_ch2_en_10_0x3 = 0x18,
    i2t_trip_ch2_en_11_0x4 = 0x20,
    i2t_trip_ch2_en_12_0x5 = 0x28,
    i2t_trip_ch2_en_13_0x6 = 0x30,
    i2t_trip_ch2_en_14_0x7 = 0x38,
    i2t_trip_ch2_en_15_0x8 = 0x40,
    i2t_trip_ch2_en_16_0x9 = 0x48,
    i2t_trip_ch2_en_1_0xA = 0x50,
    i2t_trip_ch2_en_4_0xB = 0x58,
    i2t_trip_ch2_en_2_0xC = 0x60,
    i2t_trip_ch2_en_6_0xD = 0x68,
    i2t_trip_ch2_en_5_0xE = 0x70,
    i2t_trip_ch2_en_7_0xF = 0x78,
} i2t_trip_ch2_t;

#define TPS2HC10S_I2T_CONFIG_CH2_ISWCL_CH2_MASK 0x180
#define TPS2HC10S_I2T_CONFIG_CH2_ISWCL_CH2_OFS 7

typedef enum {
    iswcl_ch2_en_1_0x0 = 0x0,
    iswcl_ch2_en_2_0x1 = 0x80,
    iswcl_ch2_en_3_0x2 = 0x100,
    iswcl_ch2_en_4_0x3 = 0x180,
} iswcl_ch2_t;

#define TPS2HC10S_I2T_CONFIG_CH2_SWCL_DLY_TMR_CH2_MASK 0x600
#define TPS2HC10S_I2T_CONFIG_CH2_SWCL_DLY_TMR_CH2_OFS 9

typedef enum {
    swcl_dly_tmr_ch2_en_1_0x0 = 0x0,
    swcl_dly_tmr_ch2_en_2_0x1 = 0x200,
    swcl_dly_tmr_ch2_en_3_0x2 = 0x400,
    swcl_dly_tmr_ch2_en_4_0x3 = 0x600,
} swcl_dly_tmr_ch2_t;

#define TPS2HC10S_I2T_CONFIG_CH2_RESERVED_50_MASK 0x3800
#define TPS2HC10S_I2T_CONFIG_CH2_RESERVED_50_OFS 11
#define TPS2HC10S_I2T_CONFIG_CH2_TCLDN_CH2_MASK 0xC000
#define TPS2HC10S_I2T_CONFIG_CH2_TCLDN_CH2_OFS 14

typedef enum {
    tcldn_ch2_en_1_0x0 = 0x0,
    tcldn_ch2_en_2_0x1 = 0x4000,
    tcldn_ch2_en_3_0x2 = 0x8000,
    tcldn_ch2_en_4_0x3 = 0xc000,
} tcldn_ch2_t;


#endif /* TPS2HCS10_H */
